<?php

/**
 * Plugin Name: Bluex Shipping
 * Plugin URI: http://plugins.bluex.cl/
 * Description: Bluex Shipping Method for WooCommerce.
 * Version: 1.4
 * Author: @YetiForWooCommerce
 * Author URI: http://plugins.bluex.cl/
 * License: GPL-3.0+
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * Domain Path: /lang
 * Text Domain: bx
 */

if (!defined('WPINC')) {
    die;
}
if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {

    function bx_shipping_method()
    {
        if (!class_exists('Bx_Shipping_Method')) {
            class Bx_Shipping_Method extends WC_Shipping_Method
            {

                public function __construct()
                {
                    $this->id                 = 'bx';
                    $this->method_title       = __('Bluex Shipping Integration', 'bx');
                    $this->method_description = __('Bluex shipping integration for WooCommerce', 'bx');
                    $this->enabled = isset($this->settings['enabled']) ? $this->settings['enabled'] : 'yes';
                    $this->title = isset($this->settings['title']) ? $this->settings['title'] : __('Bluexpress', 'bx');
                    $this->init();
                }

                function init()
                {
                    $this->init_form_fields();
                    $this->init_settings();
                    add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
                }

                function init_form_fields()
                {

                    // We will add our settings here
                    $this->form_fields = array(
                        'enabled' => array(
                            'title' => __('Enable', 'bx'),
                            'type' => 'checkbox',
                            'description' => __('Is this shipping enabled?.', 'bx'),
                            'default' => 'yes'
                        ),
                        'title' => array(
                            'title' => __('Title', 'bx'),
                            'type' => 'text',
                            'description' => __('My name is Shipping, Bluex Shipping.', 'bx'),
                            'default' => __('Bluex Shipping', 'bx')
                        ),
                        'clientAccount' => array(
                            'title' => __('Bluex Account', 'bx'),
                            'required'    => true,
                            'type' => 'text',
                            'description' => __('Your Bluex Client Account. Contact it001@bx.cl for more information.', 'bx'),
                            'default' => __('', 'bx')
                        ),
                        'bxToken' => array(
                            'title' => __('Bluex Token', 'bx'),
                            'required'    => true,
                            'type' => 'text',
                            'description' => __('Your Bluex Token. Contact it001@bx.cl for more information.', 'bx'),
                            'default' => __('', 'bx')
                        ),
                        'bxUserCode' => array(
                            'title' => __('Bluex User Code', 'bx'),
                            'required'    => true,
                            'type' => 'text',
                            'description' => __('Your Bluex User Code. Contact it001@bx.cl for more information.', 'bx'),
                            'default' => __('', 'bx')
                        ),
                        'bluexPricingRestURL' => array(
                            'title' => __('Bluex\'s Pricing API', 'bx'),
                            'required'    => true,
                            'type' => 'text',
                            'description' => __('Bluex base url for pricing rest API. Contact it001@bx.cl for more information.', 'bx'),
                            'default' => __('', 'bx')
                        ),
                        'sellerCountry' => array(
                            'title' => __('Seller\'s Store Country', 'bx'),
                            'required'    => true,
                            'type' => 'select',
                            'description' => __('From which country are you going to send the shipment?', 'bx'),
                            'default' => __('CL', 'bx'),
                            'options' => array(
                                'CL'   => __('Chile', 'bx'),
                            )
                        ),
                        'sellerDistrict' => array(
                            'title' => __('Seller\'s Store District', 'bx'),
                            'required'    => true,
                            'type' => 'select',
                            'description' => __('From which district are you going to send the shipment?', 'bx'),
                            'default' => __('SCL', 'bx'),
                            'options' => array(
                                'ATS'   => '(Arica y Parinacota)  AGUAS CALIENTES -ARI',
                                'ARZ'   => '(Arica y Parinacota)  ALTO RAMIREZ',
                                'ARI'   => '(Arica y Parinacota)  ARICA',
                                'APR'   => '(Arica y Parinacota)  AUSIPAR',
                                'AZA'   => '(Arica y Parinacota)  AZAPA',
                                'AZT'   => '(Arica y Parinacota)  AZUFRERA TACORA',
                                'BNN'   => '(Arica y Parinacota)  BELEN',
                                'ABT'   => '(Arica y Parinacota)  BRITANIA',
                                'CTM'   => '(Arica y Parinacota)  CALETA CAMARONES',
                                'ICC'   => '(Arica y Parinacota)  CALETA CHICA',
                                'CAM'   => '(Arica y Parinacota)  CAMARONES - ARICA',
                                'ACQ'   => '(Arica y Parinacota)  CAQUENA',
                                'ACC'   => '(Arica y Parinacota)  CHACUYO',
                                'ACP'   => '(Arica y Parinacota)  CHAPIQUINA',
                                'CYH'   => '(Arica y Parinacota)  CHICAYA',
                                'ACL'   => '(Arica y Parinacota)  CHOQUELIMPIE',
                                'ACZ'   => '(Arica y Parinacota)  CODPA',
                                'CQY'   => '(Arica y Parinacota)  COPAQUILLA',
                                'ACN'   => '(Arica y Parinacota)  CORONEL ALCERRECA',
                                'ACI'   => '(Arica y Parinacota)  COSAPILLA',
                                'ZYA'   => '(Arica y Parinacota)  CUYA',
                                'CZZ'   => '(Arica y Parinacota)  CUZ CUZ - ARICA',
                                'AQE'   => '(Arica y Parinacota)  ESQUINA',
                                'LGR'   => '(Arica y Parinacota)  GENERAL LAGOS',
                                'GLL'   => '(Arica y Parinacota)  GUACOLLO',
                                'ALL'   => '(Arica y Parinacota)  GUALLATIRI',
                                'AGN'   => '(Arica y Parinacota)  GUANACAHUA',
                                'ITT'   => '(Arica y Parinacota)  ITISA',
                                'JRI'   => '(Arica y Parinacota)  JURASI',
                                'CGA'   => '(Arica y Parinacota)  LAGO CHUNGARA',
                                'MKU'   => '(Arica y Parinacota)  MAILLKU',
                                'MMN'   => '(Arica y Parinacota)  MINIMINE',
                                'MIY'   => '(Arica y Parinacota)  MINITA',
                                'AMO'   => '(Arica y Parinacota)  MOLINOS',
                                'NSH'   => '(Arica y Parinacota)  NASAHUENTO',
                                'APH'   => '(Arica y Parinacota)  PACHAMA',
                                'API'   => '(Arica y Parinacota)  PARINACOTA',
                                'POC'   => '(Arica y Parinacota)  POCONCHILE',
                                'PQS'   => '(Arica y Parinacota)  PUQUISA',
                                'PTR'   => '(Arica y Parinacota)  PUTRE',
                                'QPT'   => '(Arica y Parinacota)  QUIPINTA',
                                'RAR'   => '(Arica y Parinacota)  RANCHO ARICA',
                                'AYA'   => '(Arica y Parinacota)  SOBRAYA',
                                'ASO'   => '(Arica y Parinacota)  SOCOROMA',
                                'SOR'   => '(Arica y Parinacota)  SORA',
                                'UCA'   => '(Arica y Parinacota)  SUCA',
                                'TRG'   => '(Arica y Parinacota)  TARUGUIRE',
                                'ATQ'   => '(Arica y Parinacota)  TERMAS DE CHITUNE',
                                'ATG'   => '(Arica y Parinacota)  TIGNAMAR',
                                'TCA'   => '(Arica y Parinacota)  TIMALCHACA',
                                'ATI'   => '(Arica y Parinacota)  TIMAR',
                                'AVF'   => '(Arica y Parinacota)  VILLA FRONTERA',
                                'VIU'   => '(Arica y Parinacota)  VILLA INDUSTRIAL',
                                'VIV'   => '(Arica y Parinacota)  VISVIRI',
                                'PJR'   => '(Tarapacá)  ALPAJERES',
                                'AHP'   => '(Tarapacá)  ALTO HOSPICIO',
                                'IAL'   => '(Tarapacá)  ALTUZA',
                                'ANG'   => '(Tarapacá)  ANAGUANI',
                                'CVT'   => '(Tarapacá)  ANCOVINTO',
                                'ANQ'   => '(Tarapacá)  ANCUAQUE',
                                'CTA'   => '(Tarapacá)  CALATAMBO',
                                'ICB'   => '(Tarapacá)  CALETA BUENA - IQUIQ',
                                'CMN'   => '(Tarapacá)  CAMINA',
                                'ICO'   => '(Tarapacá)  CANCOSA',
                                'ICQ'   => '(Tarapacá)  CARIQUIMA',
                                'RTA'   => '(Tarapacá)  CARITAYA',
                                'ICY'   => '(Tarapacá)  CHAPIQUITA',
                                'ICI'   => '(Tarapacá)  CHIAPA',
                                'PQA'   => '(Tarapacá)  CHIPANA',
                                'ICA'   => '(Tarapacá)  CHUSMISA',
                                'COE'   => '(Tarapacá)  COLCHANE',
                                'QLG'   => '(Tarapacá)  COLLACAGUA',
                                'CLH'   => '(Tarapacá)  COLLAHUASI',
                                'ICP'   => '(Tarapacá)  COLONIA PINTADOS',
                                'QCR'   => '(Tarapacá)  CORSA',
                                'QEP'   => '(Tarapacá)  ENQUELGA',
                                'IFB'   => '(Tarapacá)  FUERTE BAQUEDANO',
                                'ZRC'   => '(Tarapacá)  GUATACONDO',
                                'HRA'   => '(Tarapacá)  HUARA',
                                'IQQ'   => '(Tarapacá)  IQUIQUE',
                                'IIS'   => '(Tarapacá)  ISLUGA',
                                'LGC'   => '(Tarapacá)  LA HUAICA',
                                'LTI'   => '(Tarapacá)  LA TIRANA',
                                'ILI'   => '(Tarapacá)  LIRIMA',
                                'IMA'   => '(Tarapacá)  MACAYA',
                                'MAN'   => '(Tarapacá)  MAMINA',
                                'MTA'   => '(Tarapacá)  MATILLA',
                                'IMF'   => '(Tarapacá)  MINA FAKIR',
                                'IML'   => '(Tarapacá)  MINA LOBOS',
                                'BQM'   => '(Tarapacá)  MINERA QUEBRADA BLAN',
                                'IMO'   => '(Tarapacá)  MOCHA',
                                'MCL'   => '(Tarapacá)  MOCOMUCANE',
                                'NMA'   => '(Tarapacá)  NAMA',
                                'IOV'   => '(Tarapacá)  OFICINA VICTORIA',
                                'IPH'   => '(Tarapacá)  PACHICA',
                                'PKA'   => '(Tarapacá)  PALCA',
                                'OPC'   => '(Tarapacá)  PICA',
                                'PIS'   => '(Tarapacá)  PISAGUA',
                                'ZPL'   => '(Tarapacá)  PLAYA BLANCA',
                                'QPR'   => '(Tarapacá)  POROMA',
                                'PAM'   => '(Tarapacá)  POZO ALMONTE',
                                'IPP'   => '(Tarapacá)  PUERTO PATILLOS',
                                'QLB'   => '(Tarapacá)  PUNTA LOBOS',
                                'PQU'   => '(Tarapacá)  PUQUIOS - IQUIQUE',
                                'RSC'   => '(Tarapacá)  RIO SECO',
                                'RFO'   => '(Tarapacá)  SAN MARCOS - IQUIQUE',
                                'STA'   => '(Tarapacá)  SOTOCA',
                                'IUJ'   => '(Tarapacá)  TAMBILLO',
                                'ITP'   => '(Tarapacá)  TARAPACA',
                                'IVV'   => '(Tarapacá)  VILAVILA',
                                'AAV'   => '(Antofagasta)  AGUA VERDE',
                                'CAA'   => '(Antofagasta)  AGUAS BLANCAS',
                                'CTZ'   => '(Antofagasta)  ALITAR',
                                'AMR'   => '(Antofagasta)  ALTAMIRA',
                                'AMC'   => '(Antofagasta)  AMINCHA',
                                'ANF'   => '(Antofagasta)  ANTOFAGASTA',
                                'ASN'   => '(Antofagasta)  ASCOTAN',
                                'QCA'   => '(Antofagasta)  AUCANQUILCHA',
                                'CAY'   => '(Antofagasta)  AYQUINA',
                                'AZF'   => '(Antofagasta)  AZUFRERA',
                                'ATM'   => '(Antofagasta)  AZUFRERA PLATO DE SO',
                                'CBT'   => '(Antofagasta)  BANOS DE TURI',
                                'BQO'   => '(Antofagasta)  BAQUEDANO',
                                'ABL'   => '(Antofagasta)  BLANCO ENCALADA',
                                'CCZ'   => '(Antofagasta)  CALACHUZ',
                                'CJC'   => '(Antofagasta)  CALAMA',
                                'AJJ'   => '(Antofagasta)  CALETA BOTIJA',
                                'ACB'   => '(Antofagasta)  CALETA BOY',
                                'ACE'   => '(Antofagasta)  CALETA BUENA - ANTOF',
                                'AEE'   => '(Antofagasta)  CALETA EL COBRE',
                                'CMR'   => '(Antofagasta)  CAMAR',
                                'CCR'   => '(Antofagasta)  CARACOLES',
                                'CIN'   => '(Antofagasta)  CARMEN ALTO',
                                'CAP'   => '(Antofagasta)  CASPANA',
                                'CDQ'   => '(Antofagasta)  CENTINELA',
                                'ACM'   => '(Antofagasta)  CERRO MORENO',
                                'CPL'   => '(Antofagasta)  CERRO PARANAL',
                                'CHU'   => '(Antofagasta)  CHIUCHIU',
                                'QUI'   => '(Antofagasta)  CHUQUICAMATA',
                                'CFI'   => '(Antofagasta)  CIFUNCHO',
                                'ACJ'   => '(Antofagasta)  COBIJA',
                                'CCI'   => '(Antofagasta)  CONCHI   ',
                                'CCV'   => '(Antofagasta)  CONCHI VIEJO',
                                'CEY'   => '(Antofagasta)  CUPO',
                                'AEG'   => '(Antofagasta)  EL GUANACO',
                                'AEM'   => '(Antofagasta)  EL MEDANO',
                                'AEW'   => '(Antofagasta)  EL WAY',
                                'AEO'   => '(Antofagasta)  ENSUENO',
                                'SDA'   => '(Antofagasta)  ESMERALDA',
                                'AEB'   => '(Antofagasta)  ESTACION AGUA BUENA',
                                'AGC'   => '(Antofagasta)  ESTACION AGUAS BLANC',
                                'AEV'   => '(Antofagasta)  ESTACION AUGUSTA VIC',
                                'ETC'   => '(Antofagasta)  ESTACION CARCOTE',
                                'AEC'   => '(Antofagasta)  ESTACION CATALINA',
                                'CEB'   => '(Antofagasta)  ESTACION CEBOLLAR',
                                'CCB'   => '(Antofagasta)  ESTACION CERRITOS BAYOS',
                                'AEJ'   => '(Antofagasta)  ESTACION LA RIOJA',
                                'AEL'   => '(Antofagasta)  ESTACION LOS VIENTOS',
                                'AET'   => '(Antofagasta)  ESTACION MIRAJE',
                                'AMQ'   => '(Antofagasta)  ESTACION MONTURAQUI',
                                'AEH'   => '(Antofagasta)  ESTACION O`HIGGINS',
                                'APE'   => '(Antofagasta)  ESTACION PALESTINA',
                                'APZ'   => '(Antofagasta)  ESTACION PAN DE AZUC',
                                'ESA'   => '(Antofagasta)  ESTACION SOCOMPA',
                                'AVE'   => '(Antofagasta)  ESTACION VARILLA',
                                'AXA'   => '(Antofagasta)  EX OFICINA ALEMANIA',
                                'AXC'   => '(Antofagasta)  EX OFICINA CHILE',
                                'AXF'   => '(Antofagasta)  EX OFICINA FLOR DE C',
                                'FDT'   => '(Antofagasta)  FLOR DEL DESIERTO',
                                'AHO'   => '(Antofagasta)  HORNITOS - ANTOFAGAS',
                                'CJI'   => '(Antofagasta)  INCACALIRI',
                                'ZSM'   => '(Antofagasta)  ISLA SANTA MARIA',
                                'AJL'   => '(Antofagasta)  JUAN LOPEZ',
                                'LNA'   => '(Antofagasta)  LA NEGRA',
                                'LPV'   => '(Antofagasta)  LA POLVORA',
                                'CXL'   => '(Antofagasta)  LASANA',
                                'CLQ'   => '(Antofagasta)  LEQUENA',
                                'LZR'   => '(Antofagasta)  LINZOR',
                                'MTB'   => '(Antofagasta)  MANTOS BLANCOS',
                                'MAE'   => '(Antofagasta)  MARIA ELENA',
                                'MEQ'   => '(Antofagasta)  MARIA ELENA SOQUIMICH',
                                'MJS'   => '(Antofagasta)  MEJILLONES',
                                'MLZ'   => '(Antofagasta)  MELLIZOS',
                                'AMI'   => '(Antofagasta)  MICHILLA',
                                'MCD'   => '(Antofagasta)  MINA CERRO DOMINADOR',
                                'ELA'   => '(Antofagasta)  MINA EL ABRA',
                                'MLT'   => '(Antofagasta)  MINA EL LITIO',
                                'MFD'   => '(Antofagasta)  MINA FARIDE',
                                'MGY'   => '(Antofagasta)  MINA GABY',
                                'MIN'   => '(Antofagasta)  MINA LOMAS BAYAS',
                                'MIC'   => '(Antofagasta)  MINA MICHILLA',
                                'MRT'   => '(Antofagasta)  MINA RADOMIRO TOMIC',
                                'SPM'   => '(Antofagasta)  MINERA SPENCER',
                                'MZL'   => '(Antofagasta)  MINERA ZALDIVAR',
                                'ALQ'   => '(Antofagasta)  OFICINA PEDRO DE VAL',
                                'OVR'   => '(Antofagasta)  OFICINA VERGARA',
                                'OLL'   => '(Antofagasta)  OLLAGUE',
                                'APP'   => '(Antofagasta)  PAPOSO',
                                'PRL'   => '(Antofagasta)  PARANAL',
                                'PNI'   => '(Antofagasta)  PEINE',
                                'CXP'   => '(Antofagasta)  POLAN',
                                'APC'   => '(Antofagasta)  PUERTO COLOSO',
                                'RMA'   => '(Antofagasta)  PURITAMA',
                                'CQG'   => '(Antofagasta)  QUILLAGUA',
                                'RAN'   => '(Antofagasta)  RANCHO ANTOFAGASTA',
                                'RGS'   => '(Antofagasta)  RIO GRANDE - CALAMA',
                                'CSB'   => '(Antofagasta)  SAN BARTOLO',
                                'ASC'   => '(Antofagasta)  SAN CRISTOBAL',
                                'SJE'   => '(Antofagasta)  SAN JOSE  ',
                                'SPD'   => '(Antofagasta)  SAN PEDRO DE ATACAMA',
                                'SPX'   => '(Antofagasta)  SAN PEDRO DE ATACAMA',
                                'CSR'   => '(Antofagasta)  SANTA ROSA - CALAMA',
                                'SGD'   => '(Antofagasta)  SIERRA GORDA',
                                'CSE'   => '(Antofagasta)  SOCAIRE',
                                'CTB'   => '(Antofagasta)  TALABRE',
                                'TTL'   => '(Antofagasta)  TALTAL',
                                'CTP'   => '(Antofagasta)  TILO POZO',
                                'CIL'   => '(Antofagasta)  TILOMONTE',
                                'TCO'   => '(Antofagasta)  TOCONAO',
                                'COV'   => '(Antofagasta)  TOCONCE',
                                'TOC'   => '(Antofagasta)  TOCOPILLA',
                                'CTN'   => '(Antofagasta)  TUINA',
                                'TTR'   => '(Antofagasta)  TURI',
                                'VZV'   => '(Atacama)  ALGARROBAL',
                                'ADC'   => '(Atacama)  ALTO DEL CARMEN',
                                'AMN'   => '(Atacama)  AMOLANAS',
                                'CBH'   => '(Atacama)  BAHIA INGLESA',
                                'BQQ'   => '(Atacama)  BARRANQUILLAS',
                                'QBQ'   => '(Atacama)  BOCAMINA',
                                'VCQ'   => '(Atacama)  CACHIYUYO',
                                'CLR'   => '(Atacama)  CALDERA',
                                'VCL'   => '(Atacama)  CALETA CHANARAL',
                                'CCM'   => '(Atacama)  CALETA DEL MEDIO',
                                'QCP'   => '(Atacama)  CALETA PAJONAL',
                                'TSC'   => '(Atacama)  CALETA SARCO',
                                'TAG'   => '(Atacama)  CANTO DE AGUA',
                                'VCR'   => '(Atacama)  CARRIZAL BAJO',
                                'VCI'   => '(Atacama)  CARRIZALILLO',
                                'CHN'   => '(Atacama)  CHANARAL - COPIAPO',
                                'CYO'   => '(Atacama)  CHANARCILLO',
                                'QCI'   => '(Atacama)  COLINA',
                                'VCO'   => '(Atacama)  CONAY',
                                'CPO'   => '(Atacama)  COPIAPO',
                                'DAG'   => '(Atacama)  DIEGO DE ALMAGRO',
                                'DYK'   => '(Atacama)  DOMEYKO',
                                'EBL'   => '(Atacama)  EL BORATILLO',
                                'VOB'   => '(Atacama)  EL DONKEY',
                                'ZMJ'   => '(Atacama)  EL NEVADO',
                                'QPN'   => '(Atacama)  EL PINO',
                                'TMO'   => '(Atacama)  EL RETAMO',
                                'ESL'   => '(Atacama)  EL SALADO',
                                'ESR'   => '(Atacama)  EL SALVADOR',
                                'VET'   => '(Atacama)  EL TRANSITO - SERENA',
                                'CVO'   => '(Atacama)  EL VOLCAN',
                                'CBD'   => '(Atacama)  ELISA DE BORDO',
                                'CFC'   => '(Atacama)  FINCA DE CHANARAL',
                                'CFL'   => '(Atacama)  FLAMENCO',
                                'FRN'   => '(Atacama)  FREIRINA',
                                'CHX'   => '(Atacama)  HACIENDA CASTILLA',
                                'QHN'   => '(Atacama)  HORNITOS - COPIAPO',
                                'HCO'   => '(Atacama)  HUASCO',
                                'HCB'   => '(Atacama)  HUASCO BAJO',
                                'IRO'   => '(Atacama)  INCA DE ORO',
                                'VJU'   => '(Atacama)  JUNTA VALERIANO',
                                'VLA'   => '(Atacama)  LA ARENA ',
                                'VFR'   => '(Atacama)  LA FRAGUITA',
                                'CGD'   => '(Atacama)  LA GUARDIA',
                                'LHI'   => '(Atacama)  LA HIGUERA',
                                'VLH'   => '(Atacama)  LA HIGUERITA',
                                'VHY'   => '(Atacama)  LA HOYADA',
                                'QLA'   => '(Atacama)  LA OLA',
                                'CXA'   => '(Atacama)  LA PUERTA',
                                'VLB'   => '(Atacama)  LABRAR',
                                'ZTA'   => '(Atacama)  LAGUNA GRANDE',
                                'CLJ'   => '(Atacama)  LAS JUNTAS',
                                'LLT'   => '(Atacama)  LLANTA',
                                'CLZ'   => '(Atacama)  LOS AZULES',
                                'VLO'   => '(Atacama)  LOS COLORADOS',
                                'CLW'   => '(Atacama)  LOS LOROS',
                                'CXQ'   => '(Atacama)  LOS TOYOS',
                                'VMT'   => '(Atacama)  MAITENCILLO - CALERA',
                                'VMI'   => '(Atacama)  MINA ALGARROBO',
                                'MCR'   => '(Atacama)  MINA CANDELARIA',
                                'CLC'   => '(Atacama)  MINA CHIVATO',
                                'QMD'   => '(Atacama)  MINA DICHOSA',
                                'CMQ'   => '(Atacama)  MINA LA COIPA',
                                'QME'   => '(Atacama)  MINA LA ESTRELLA',
                                'MTE'   => '(Atacama)  MINA MARTE',
                                'RSO'   => '(Atacama)  MINA ROSARIO',
                                'VMR'   => '(Atacama)  MIRAFLORES - SERENA',
                                'MNN'   => '(Atacama)  MONTANDON',
                                'CNN'   => '(Atacama)  NANTOCO',
                                'OBT'   => '(Atacama)  OBISPITO',
                                'VOS'   => '(Atacama)  OBSERVATORIO CAMPANA',
                                'LSX'   => '(Atacama)  OBSERVATORIO LA SILL',
                                'PPE'   => '(Atacama)  PAIPOTE',
                                'CPZ'   => '(Atacama)  PAN DE AZUCAR - COPI',
                                'QPL'   => '(Atacama)  PASTOS LARGOS',
                                'QPO'   => '(Atacama)  PLAYA REFUGIO',
                                'PTS'   => '(Atacama)  POTRERILLOS',
                                'CPF'   => '(Atacama)  PUERTO FINO',
                                'CPV'   => '(Atacama)  PUERTO VIEJO',
                                'QPQ'   => '(Atacama)  PUQUIOS',
                                'RCD'   => '(Atacama)  RANCHO CALDERA',
                                'SAI'   => '(Atacama)  SAN ANTONIO - COPIAP',
                                'VSA'   => '(Atacama)  SAN FELIX',
                                'QTR'   => '(Atacama)  TERMAS DE RIO NEGRO',
                                'TRM'   => '(Atacama)  TIERRA AMARILLA',
                                'CTX'   => '(Atacama)  TOTORAL',
                                'RQM'   => '(Atacama)  TOTORALILLO',
                                'CVX'   => '(Atacama)  VALLE HERMOSO',
                                'VAL'   => '(Atacama)  VALLENAR',
                                'QVC'   => '(Atacama)  VEGAS DE CHANARAL AL',
                                'AGG'   => '(Coquimbo)  AGUA GRANDE',
                                'MRR'   => '(Coquimbo)  ALCOHUAS',
                                'RRG'   => '(Coquimbo)  ALGARROBITO - OVALLE',
                                'ZAM'   => '(Coquimbo)  ALMENDRALILLO',
                                'ALT'   => '(Coquimbo)  ALMIRANTE LATORRE',
                                'OAY'   => '(Coquimbo)  ALTO BUEY',
                                'AVS'   => '(Coquimbo)  ALTOVALSOL',
                                'ACO'   => '(Coquimbo)  ANDACOLLO - LA SEREN',
                                'AVU'   => '(Coquimbo)  ANDACOLLO HOLDING',
                                'ABG'   => '(Coquimbo)  ARBOLEDA GRANDE',
                                'LBW'   => '(Coquimbo)  BALALA',
                                'OBG'   => '(Coquimbo)  BANOS DEL GORDITO',
                                'LBJ'   => '(Coquimbo)  BANOS DEL TORO',
                                'BRR'   => '(Coquimbo)  BARRANCAS',
                                'RRB'   => '(Coquimbo)  BARRAZA',
                                'ZBG'   => '(Coquimbo)  BATUCO - CALERA',
                                'XBC'   => '(Coquimbo)  BOCATOMA',
                                'ANS'   => '(Coquimbo)  CAIMANES',
                                'RCC'   => '(Coquimbo)  CALETA MORRITOS',
                                'CRI'   => '(Coquimbo)  CAMARICO',
                                'RQV'   => '(Coquimbo)  CAMARICO VIEJO',
                                'CNE'   => '(Coquimbo)  CANELA',
                                'ZNK'   => '(Coquimbo)  CAREN - CALERA',
                                'KEN'   => '(Coquimbo)  CAREN - OVALLE',
                                'LCR'   => '(Coquimbo)  CASERONES',
                                'ZOQ'   => '(Coquimbo)  CASUTO',
                                'RCM'   => '(Coquimbo)  CENTRAL LOS MOLLES',
                                'CTY'   => '(Coquimbo)  CERRILLOS DE TAMAYA',
                                'AGA'   => '(Coquimbo)  CHALINGA',
                                'LHH'   => '(Coquimbo)  CHANAR ',
                                'CHZ'   => '(Coquimbo)  CHANARAL ALTO - OVAL',
                                'LKK'   => '(Coquimbo)  CHAPILCA',
                                'LNI'   => '(Coquimbo)  CHELLEPIN',
                                'ZOA'   => '(Coquimbo)  CHIGUALOCO',
                                'OCT'   => '(Coquimbo)  CHILECITO',
                                'OCH'   => '(Coquimbo)  CHINEO',
                                'ONG'   => '(Coquimbo)  CHINGAY',
                                'CPA'   => '(Coquimbo)  CHOAPA',
                                'LKM'   => '(Coquimbo)  CHOROS BAJOS',
                                'LGY'   => '(Coquimbo)  CHUNGUNGO',
                                'CGS'   => '(Coquimbo)  COCHIGUAS',
                                'CCY'   => '(Coquimbo)  COCUA',
                                'RCT'   => '(Coquimbo)  COGOTI',
                                'ZNP'   => '(Coquimbo)  COIRON',
                                'COB'   => '(Coquimbo)  COMBARBALA',
                                'LCO'   => '(Coquimbo)  CONDORIACO',
                                'LCQ'   => '(Coquimbo)  COQUIMBITO',
                                'COQ'   => '(Coquimbo)  COQUIMBO',
                                'RQO'   => '(Coquimbo)  CORRAL QUEMADO',
                                'CEA'   => '(Coquimbo)  CORTADERA',
                                'AZZ'   => '(Coquimbo)  CUZ CUZ - CALERA',
                                'DTS'   => '(Coquimbo)  DIAGUITAS',
                                'REA'   => '(Coquimbo)  EL ALTAR',
                                'OEC'   => '(Coquimbo)  EL CARRIZAL',
                                'HAY'   => '(Coquimbo)  EL CHACAY',
                                'LEI'   => '(Coquimbo)  EL ISLON',
                                'REM'   => '(Coquimbo)  EL MAITEN',
                                'RMQ'   => '(Coquimbo)  EL MAQUI ',
                                'EOV'   => '(Coquimbo)  EL OLIVO',
                                'EPI'   => '(Coquimbo)  EL PALQUI',
                                'PON'   => '(Coquimbo)  EL PENON - LA SERENA',
                                'LER'   => '(Coquimbo)  EL ROMERAL - SERENA',
                                'LEM'   => '(Coquimbo)  EL ROMERAL - SERENA',
                                'ZET'   => '(Coquimbo)  EL TAMBO - CALERA',
                                'TBE'   => '(Coquimbo)  EL TAMBO - LA SERENA',
                                'TFO'   => '(Coquimbo)  EL TOFO',
                                'ZFA'   => '(Coquimbo)  FARELLON SANCHEZ',
                                'GHC'   => '(Coquimbo)  GUACHALALUME',
                                'OGT'   => '(Coquimbo)  GUAMALATA',
                                'RGU'   => '(Coquimbo)  GUAMPULLA',
                                'GQS'   => '(Coquimbo)  GUANAQUEROS',
                                'ZIV'   => '(Coquimbo)  GUANGALI',
                                'LGU'   => '(Coquimbo)  GUANTA',
                                'GUT'   => '(Coquimbo)  GUATULAME',
                                'XMR'   => '(Coquimbo)  HACIENDA LOS ANDES',
                                'RHG'   => '(Coquimbo)  HIGUERITAS',
                                'OHY'   => '(Coquimbo)  HILARICOS',
                                'ZHT'   => '(Coquimbo)  HUENTELAUQUEN',
                                'ZHN'   => '(Coquimbo)  HUINTIL',
                                'RHT'   => '(Coquimbo)  HURTADO',
                                'ILL'   => '(Coquimbo)  ILLAPEL',
                                'LIH'   => '(Coquimbo)  INCAGUASI',
                                'ZJO'   => '(Coquimbo)  JORQUERA',
                                'LJZ'   => '(Coquimbo)  JUNTAS DEL TORO',
                                'RLG'   => '(Coquimbo)  LA AGUADA',
                                'OLB'   => '(Coquimbo)  LA CHIMBA',
                                'GOS'   => '(Coquimbo)  LA COMPANIA - SERENA',
                                'RLF'   => '(Coquimbo)  LA FUNDINA',
                                'LRR'   => '(Coquimbo)  LA HERRADURA',
                                'LHC'   => '(Coquimbo)  LA HIGUERA - LA SERE',
                                'YCV'   => '(Coquimbo)  LA LAJA',
                                'RLU'   => '(Coquimbo)  LA LIGUA BAJO',
                                'OLP'   => '(Coquimbo)  LA PLACILLA',
                                'LSC'   => '(Coquimbo)  LA SERENA',
                                'LAT'   => '(Coquimbo)  LA TORRE',
                                'LBT'   => '(Coquimbo)  LAMBERT',
                                'RLB'   => '(Coquimbo)  LAS BREAS - OVALLE',
                                'MQZ'   => '(Coquimbo)  LAS BREAS - SERENA',
                                'LZC'   => '(Coquimbo)  LAS CANAS',
                                'LLS'   => '(Coquimbo)  LAS CARDAS',
                                'LZZ'   => '(Coquimbo)  LAS COLORADAS',
                                'LHD'   => '(Coquimbo)  LAS HEDIONDAS',
                                'RLJ'   => '(Coquimbo)  LAS JUNTAS - OVALLE',
                                'LMS'   => '(Coquimbo)  LAS MOLLACAS',
                                'ZKZ'   => '(Coquimbo)  LAS PIRCAS',
                                'RLR'   => '(Coquimbo)  LAS RAMADAS',
                                'RSE'   => '(Coquimbo)  LAS ROJAS',
                                'LTC'   => '(Coquimbo)  LAS TACAS',
                                'ZVH'   => '(Coquimbo)  LIMAHUIDA',
                                'RLI'   => '(Coquimbo)  LIMARI',
                                'RLL'   => '(Coquimbo)  LITIPAMPA',
                                'OLH'   => '(Coquimbo)  LLAHUIN',
                                'LLG'   => '(Coquimbo)  LLANOS DE GUANTA',
                                'LLP'   => '(Coquimbo)  LLIMPO',
                                'ZKK'   => '(Coquimbo)  LOS ERMITANOS',
                                'LHB'   => '(Coquimbo)  LOS HORNOS',
                                'LMO'   => '(Coquimbo)  LOS MOLLES',
                                'LSO'   => '(Coquimbo)  LOS PELADEROS',
                                'LZP'   => '(Coquimbo)  LOS PERALES - OVALLE',
                                'LVL'   => '(Coquimbo)  LOS VILOS',
                                'RMH'   => '(Coquimbo)  MANTOS DE HORNILLOS',
                                'ZMC'   => '(Coquimbo)  MATANCILLA',
                                'ZMR'   => '(Coquimbo)  MAURO',
                                'LMX'   => '(Coquimbo)  MINA DEL INDIO',
                                'ZMH'   => '(Coquimbo)  MINCHA',
                                'ZMM'   => '(Coquimbo)  MINCHA SUR',
                                'LMG'   => '(Coquimbo)  MONTE GRANDE',
                                'MPC'   => '(Coquimbo)  MONTE PATRIA',
                                'NEQ'   => '(Coquimbo)  NUEVA ELQUI',
                                'LOO'   => '(Coquimbo)  OBSERVATORIO TOLOLO',
                                'OTR'   => '(Coquimbo)  OTAROLA',
                                'OVL'   => '(Coquimbo)  OVALLE',
                                'RPB'   => '(Coquimbo)  PABELLON - OVALLE',
                                'PIC'   => '(Coquimbo)  PACHINGO',
                                'PHO'   => '(Coquimbo)  PAIHUANO',
                                'PZC'   => '(Coquimbo)  PALQUIAL',
                                'LPZ'   => '(Coquimbo)  PAN DE AZUCAR - SERE',
                                'OPA'   => '(Coquimbo)  PARMA',
                                'RGR'   => '(Coquimbo)  PEDREGAL',
                                'RPJ'   => '(Coquimbo)  PEJERREYES',
                                'OPB'   => '(Coquimbo)  PENA BLANCA',
                                'PLB'   => '(Coquimbo)  PENUELAS - LA SERENA',
                                'PLV'   => '(Coquimbo)  PERALILLO - SERENA',
                                'RPI'   => '(Coquimbo)  PICHASCA',
                                'PCH'   => '(Coquimbo)  PICHIDANGUI',
                                'ELQ'   => '(Coquimbo)  PISCO ELQUI',
                                'PLM'   => '(Coquimbo)  PLACILLA - COQUIMBO',
                                'XZH'   => '(Coquimbo)  POZA HONDA',
                                'POZ'   => '(Coquimbo)  PUERTO OSCURO',
                                'PVO'   => '(Coquimbo)  PUERTO VELERO',
                                'PTQ'   => '(Coquimbo)  PUNITAQUI',
                                'PHS'   => '(Coquimbo)  PUNTA CHOROS',
                                'LOI'   => '(Coquimbo)  PUPIO',
                                'QWR'   => '(Coquimbo)  QUEBRADA SECA',
                                'ZQO'   => '(Coquimbo)  QUELON',
                                'ZQM'   => '(Coquimbo)  QUILIMARI',
                                'QWQ'   => '(Coquimbo)  QUILITAPIA',
                                'ZTL'   => '(Coquimbo)  RABANALES',
                                'RQW'   => '(Coquimbo)  RAPEL - OVALLE',
                                'RTG'   => '(Coquimbo)  RECOLETA',
                                'RTO'   => '(Coquimbo)  RETIRO - COQUIMBO',
                                'RHU'   => '(Coquimbo)  RIO HURTADO',
                                'LRV'   => '(Coquimbo)  RIVADAVIA',
                                'SCA'   => '(Coquimbo)  SALAMANCA',
                                'RVG'   => '(Coquimbo)  SAMO ALTO',
                                'RVF'   => '(Coquimbo)  SAMO BAJO',
                                'ZSG'   => '(Coquimbo)  SAN AGUSTIN',
                                'RFG'   => '(Coquimbo)  SAN LORENZO - OVALLE',
                                'SMC'   => '(Coquimbo)  SAN MARCOS - OVALLE',
                                'XPB'   => '(Coquimbo)  SAN PABLO',
                                'SSC'   => '(Coquimbo)  SANTA CECILIA',
                                'TAL'   => '(Coquimbo)  SOL NACIENTE',
                                'SOZ'   => '(Coquimbo)  SOTAQUI',
                                'TNS'   => '(Coquimbo)  TEATINOS',
                                'SQT'   => '(Coquimbo)  TERMAS DE SOCO',
                                'LTB'   => '(Coquimbo)  TIERRAS BLANCAS',
                                'ZTI'   => '(Coquimbo)  TILAMA',
                                'TGY'   => '(Coquimbo)  TONGOY',
                                'TTZ'   => '(Coquimbo)  TOTORALILLO - CALERA',
                                'TOT'   => '(Coquimbo)  TOTORALILLO - COQUIM',
                                'LTH'   => '(Coquimbo)  TRAPICHE - LA SERENA',
                                'TCS'   => '(Coquimbo)  TRES CRUCES',
                                'TNH'   => '(Coquimbo)  TULAHUEN',
                                'ZTU'   => '(Coquimbo)  TUNGA NORTE',
                                'ZTN'   => '(Coquimbo)  TUNGA SUR',
                                'ZOV'   => '(Coquimbo)  VALDIVIA - OVALLE',
                                'LVR'   => '(Coquimbo)  VARILLAR',
                                'VCA'   => '(Coquimbo)  VICUNA',
                                'LVT'   => '(Coquimbo)  VINITA BAJA',
                                'ZPF'   => '(Coquimbo)  ZAPALLAR',
                                'ABO'   => '(Valparaiso)  ALGARROBO - MELIPILL',
                                'ZAI'   => '(Valparaiso)  ALICAHUE',
                                'ZAT'   => '(Valparaiso)  ARTIFICIO',
                                'CDO'   => '(Valparaiso)  CABILDO',
                                'CGU'   => '(Valparaiso)  CACHAGUA',
                                'LNO'   => '(Valparaiso)  CALETA HORCON',
                                'LAR'   => '(Valparaiso)  CALETA POLCURA',
                                'KCD'   => '(Valparaiso)  CALETAS LAS DOCAS',
                                'CLG'   => '(Valparaiso)  CALLE LARGA',
                                'ZZC'   => '(Valparaiso)  CANELA ALTA',
                                'CNB'   => '(Valparaiso)  CANELA BAJA',
                                'CRT'   => '(Valparaiso)  CARTAGENA',
                                'CBC'   => '(Valparaiso)  CASABLANCA',
                                'PIL'   => '(Valparaiso)  CATAPILCO',
                                'CAT'   => '(Valparaiso)  CATEMU',
                                'CSP'   => '(Valparaiso)  CERRILLOS DE SAN FEL',
                                'SHW'   => '(Valparaiso)  CHAGRES',
                                'LOA'   => '(Valparaiso)  CHALACO',
                                'OLC'   => '(Valparaiso)  CHINCOLCO',
                                'CON'   => '(Valparaiso)  CONCON',
                                'AZU'   => '(Valparaiso)  COSTA AZUL',
                                'CRM'   => '(Valparaiso)  CURIMON',
                                'EBT'   => '(Valparaiso)  EL BELLOTO',
                                'KEC'   => '(Valparaiso)  EL CARPINTERO',
                                'SWC'   => '(Valparaiso)  EL CERRADO',
                                'ZEC'   => '(Valparaiso)  EL COBRE - CALERA',
                                'SOW'   => '(Valparaiso)  EL COBRE - LOS ANDES',
                                'ZEG'   => '(Valparaiso)  EL GUAYACAN',
                                'ZEI'   => '(Valparaiso)  EL INGENIO',
                                'EML'   => '(Valparaiso)  EL MELON',
                                'EQO'   => '(Valparaiso)  EL QUISCO',
                                'ZQD'   => '(Valparaiso)  EL RINCON',
                                'ETB'   => '(Valparaiso)  EL TABO',
                                'STY'   => '(Valparaiso)  EL TARTARO',
                                'KER'   => '(Valparaiso)  EL TURCO',
                                'SGY'   => '(Valparaiso)  GRANALLA',
                                'ZGR'   => '(Valparaiso)  GRANIZO',
                                'SGZ'   => '(Valparaiso)  GUARDIA VIEJA',
                                'ZHR'   => '(Valparaiso)  HIERRO VIEJO',
                                'HJS'   => '(Valparaiso)  HIJUELAS',
                                'IPC'   => '(Valparaiso)  ISLA DE PASCUA',
                                'JFZ'   => '(Valparaiso)  ISLA JUAN FERNANDEZ',
                                'INE'   => '(Valparaiso)  ISLA NEGRA',
                                'JHL'   => '(Valparaiso)  JAHUEL',
                                'SJH'   => '(Valparaiso)  JUNCAL',
                                'ZLC'   => '(Valparaiso)  LA CALERA',
                                'LCZ'   => '(Valparaiso)  LA CRUZ - CALERA',
                                'LGN'   => '(Valparaiso)  LA LAGUNA',
                                'LLC'   => '(Valparaiso)  LA LIGUA',
                                'LAO'   => '(Valparaiso)  LA MORA',
                                'ZGC'   => '(Valparaiso)  LA PATAGUA',
                                'QZC'   => '(Valparaiso)  LA QUEBRADA - CALERA',
                                'KLR'   => '(Valparaiso)  LA RETUCA',
                                'XLV'   => '(Valparaiso)  LA VINA ',
                                'LAV'   => '(Valparaiso)  LAGUNA VERDE',
                                'KLL'   => '(Valparaiso)  LAGUNILLAS',
                                'LCX'   => '(Valparaiso)  LAS CRUCES',
                                'KHD'   => '(Valparaiso)  LAS DICHAS',
                                'KME'   => '(Valparaiso)  LAS MERCEDES',
                                'LSA'   => '(Valparaiso)  LAS PALMAS',
                                'KLT'   => '(Valparaiso)  LAS TABLAS',
                                'KLY'   => '(Valparaiso)  LEYDA',
                                'LIC'   => '(Valparaiso)  LIMACHE',
                                'LLY'   => '(Valparaiso)  LLAILLAY',
                                'LLO'   => '(Valparaiso)  LLO-LLEO',
                                'SLZ'   => '(Valparaiso)  LO  ERRAZURIZ',
                                'ABA'   => '(Valparaiso)  LO ABARCA',
                                'KLG'   => '(Valparaiso)  LO GALLARDO',
                                'KLO'   => '(Valparaiso)  LO OROZCO',
                                'KLV'   => '(Valparaiso)  LO VASQUEZ',
                                'GMA'   => '(Valparaiso)  LONGOTOMA',
                                'LOB'   => '(Valparaiso)  LOS ANDES',
                                'MTC'   => '(Valparaiso)  MAITENCILLO - CALERA',
                                'ZMU'   => '(Valparaiso)  MANUEL MONTT',
                                'ZMS'   => '(Valparaiso)  MINA EL ROSARIO',
                                'MRL'   => '(Valparaiso)  MIRASOL',
                                'SMQ'   => '(Valparaiso)  MONTENEGRO',
                                'SNW'   => '(Valparaiso)  NILHUE',
                                'NOG'   => '(Valparaiso)  NOGALES',
                                'SOX'   => '(Valparaiso)  OCOA',
                                'OLM'   => '(Valparaiso)  OLMUE',
                                'PNQ'   => '(Valparaiso)  PANQUEHUE',
                                'PPO'   => '(Valparaiso)  PAPUDO',
                                'PUA'   => '(Valparaiso)  PEDEGUA',
                                'ZDR'   => '(Valparaiso)  PEDERNAL',
                                'PBA'   => '(Valparaiso)  PENABLANCA',
                                'KPE'   => '(Valparaiso)  PENUELAS - V DEL MAR',
                                'PTK'   => '(Valparaiso)  PETORCA',
                                'PZY'   => '(Valparaiso)  PICHICUY',
                                'PLP'   => '(Valparaiso)  PLACILLA - V DEL MAR',
                                'PRT'   => '(Valparaiso)  PORTILLO',
                                'PCV'   => '(Valparaiso)  PUCHUNCAVI',
                                'KPC'   => '(Valparaiso)  PUNTA CURAUMILLA',
                                'KPT'   => '(Valparaiso)  PUNTA DE TRALCA',
                                'PUT'   => '(Valparaiso)  PUTAENDO',
                                'ZQB'   => '(Valparaiso)  QUEBRADA ALVARADO',
                                'QTA'   => '(Valparaiso)  QUILLOTA',
                                'QPE'   => '(Valparaiso)  QUILPUE',
                                'ZQQ'   => '(Valparaiso)  QUINQUIMO',
                                'QTY'   => '(Valparaiso)  QUINTAY',
                                'QTO'   => '(Valparaiso)  QUINTERO',
                                'RCA'   => '(Valparaiso)  RENACA',
                                'SRP'   => '(Valparaiso)  RESGUARDO LOS PATOS',
                                'RDA'   => '(Valparaiso)  RINCONADA - LOS ANDE',
                                'SRG'   => '(Valparaiso)  RINCONADA DE GUZMAN',
                                'SRS'   => '(Valparaiso)  RINCONADA DE SILVA',
                                'SRB'   => '(Valparaiso)  RIO BLANCO',
                                'ZRV'   => '(Valparaiso)  RITOQUE',
                                'SER'   => '(Valparaiso)  RUNGUE',
                                'SDO'   => '(Valparaiso)  SALADILLO',
                                'SSD'   => '(Valparaiso)  SALTO DEL SOLDADO',
                                'SNT'   => '(Valparaiso)  SAN ANTONIO - MELIP.',
                                'SEN'   => '(Valparaiso)  SAN ESTEBAN',
                                'SFP'   => '(Valparaiso)  SAN FELIPE',
                                'KSG'   => '(Valparaiso)  SAN GERONIMO',
                                'ZSL'   => '(Valparaiso)  SAN LORENZO - CALERA',
                                'ZDD'   => '(Valparaiso)  SAN PEDRO - CALERA',
                                'SSB'   => '(Valparaiso)  SAN SEBASTIAN - MELI',
                                'SRI'   => '(Valparaiso)  SANTA MARIA',
                                'ZST'   => '(Valparaiso)  SANTA MARTA - CALERA',
                                'SDC'   => '(Valparaiso)  SANTO DOMINGO',
                                'KTH'   => '(Valparaiso)  TAPIHUE',
                                'TJL'   => '(Valparaiso)  TERMAS DE JAHUEL',
                                'ZEW'   => '(Valparaiso)  TRAPICHE - CALERA',
                                'TRE'   => '(Valparaiso)  TRES FUERTES',
                                'BAG'   => '(Valparaiso)  VALLE ALEGRE',
                                'VAP'   => '(Valparaiso)  VALPARAISO',
                                'VTA'   => '(Valparaiso)  VENTANAS',
                                'VIA'   => '(Valparaiso)  VILLA ALEMANA',
                                'KNA'   => '(Valparaiso)  VINA DEL MAR',
                                'ZAR'   => '(Valparaiso)  ZAPALLAR - CALERA',
                                'AMB'   => '(Metropolitana de Santiago)  AEROPUERTO ARTURO ME',
                                'ALH'   => '(Metropolitana de Santiago)  ALHUE',
                                'SAJ'   => '(Metropolitana de Santiago)  ALTO JAHUEL',
                                'SBX'   => '(Metropolitana de Santiago)  BATUCO - SANTIAGO',
                                'SBR'   => '(Metropolitana de Santiago)  BOLLENAR',
                                'BUU'   => '(Metropolitana de Santiago)  BUCALEMU',
                                'ZBU'   => '(Metropolitana de Santiago)  BUIN',
                                'CDT'   => '(Metropolitana de Santiago)  CALERA DE TANGO',
                                'RRI'   => '(Metropolitana de Santiago)  CERRILLOS - SANTIAGO',
                                'CBO'   => '(Metropolitana de Santiago)  CERRO BLANCO',
                                'CNV'   => '(Metropolitana de Santiago)  CERRO NAVIA',
                                'SCY'   => '(Metropolitana de Santiago)  CHACAY',
                                'CHP'   => '(Metropolitana de Santiago)  CHAMPA',
                                'CHW'   => '(Metropolitana de Santiago)  CHICUREO',
                                'AAN'   => '(Metropolitana de Santiago)  CHOCALAN ',
                                'SCM'   => '(Metropolitana de Santiago)  CHOROMBO',
                                'ZCD'   => '(Metropolitana de Santiago)  CODIGUA',
                                'COL'   => '(Metropolitana de Santiago)  COLINA - SANTIAGO',
                                'CLY'   => '(Metropolitana de Santiago)  COLLIGUAY',
                                'CNH'   => '(Metropolitana de Santiago)  CONCHALI',
                                'CZA'   => '(Metropolitana de Santiago)  CRUCE LAS ARANAS',
                                'CLP'   => '(Metropolitana de Santiago)  CULIPRAN',
                                'CVI'   => '(Metropolitana de Santiago)  CURACAVI',
                                'EBO'   => '(Metropolitana de Santiago)  EL BOSQUE',
                                'SEC'   => '(Metropolitana de Santiago)  EL CANELO',
                                'SMI'   => '(Metropolitana de Santiago)  EL MANZANILLO',
                                'EME'   => '(Metropolitana de Santiago)  EL MELOCOTON',
                                'MMZ'   => '(Metropolitana de Santiago)  EL MEMBRILLO',
                                'ZTE'   => '(Metropolitana de Santiago)  EL MONTE',
                                'EPC'   => '(Metropolitana de Santiago)  EL PAICO',
                                'TTO'   => '(Metropolitana de Santiago)  EL TRANSITO - SANTIA',
                                'TRB'   => '(Metropolitana de Santiago)  EL TREBOL',
                                'SVV'   => '(Metropolitana de Santiago)  EL VOLCAN - SANTIAGO',
                                'ESB'   => '(Metropolitana de Santiago)  ESMERALDA - SANTIAGO',
                                'ECE'   => '(Metropolitana de Santiago)  ESTACION CENTRAL',
                                'FAR'   => '(Metropolitana de Santiago)  FARELLONES',
                                'SYY'   => '(Metropolitana de Santiago)  GUAYACAN',
                                'HOS'   => '(Metropolitana de Santiago)  HOSPITAL',
                                'HRB'   => '(Metropolitana de Santiago)  HUECHURABA',
                                'SHU'   => '(Metropolitana de Santiago)  HUELQUEN',
                                'IDP'   => '(Metropolitana de Santiago)  INDEPENDENCIA',
                                'IDM'   => '(Metropolitana de Santiago)  ISLA DE MAIPO',
                                'IPQ'   => '(Metropolitana de Santiago)  ISLA DE PIRQUE',
                                'LCN'   => '(Metropolitana de Santiago)  LA CISTERNA',
                                'LZU'   => '(Metropolitana de Santiago)  LA CRUZ MELIPILLA',
                                'LFD'   => '(Metropolitana de Santiago)  LA FLORIDA',
                                'LGJ'   => '(Metropolitana de Santiago)  LA GRANJA',
                                'SLO'   => '(Metropolitana de Santiago)  LA OBRA',
                                'LPT'   => '(Metropolitana de Santiago)  LA PINTANA',
                                'LRN'   => '(Metropolitana de Santiago)  LA REINA',
                                'LSG'   => '(Metropolitana de Santiago)  LAMPA',
                                'SLN'   => '(Metropolitana de Santiago)  LAS CANTERAS',
                                'LCD'   => '(Metropolitana de Santiago)  LAS CONDES',
                                'SLM'   => '(Metropolitana de Santiago)  LAS MARIPOSAS - MELI',
                                'SLS'   => '(Metropolitana de Santiago)  LAS MELOSAS',
                                'SLV'   => '(Metropolitana de Santiago)  LAS VERTIENTES',
                                'SLD'   => '(Metropolitana de Santiago)  LINDEROS',
                                'LBR'   => '(Metropolitana de Santiago)  LO BARNECHEA',
                                'HAC'   => '(Metropolitana de Santiago)  LO CHACON',
                                'LEP'   => '(Metropolitana de Santiago)  LO ESPEJO',
                                'LPR'   => '(Metropolitana de Santiago)  LO PRADO',
                                'STQ'   => '(Metropolitana de Santiago)  LO VALDES',
                                'KET'   => '(Metropolitana de Santiago)  LOLENCO - MELIPILLA',
                                'ZKU'   => '(Metropolitana de Santiago)  LONCHA',
                                'LQN'   => '(Metropolitana de Santiago)  LONQUEN',
                                'LYR'   => '(Metropolitana de Santiago)  LOS ARRAYANES',
                                'SMT'   => '(Metropolitana de Santiago)  LOS MAITENES',
                                'XQT'   => '(Metropolitana de Santiago)  LOS QUELTEHUES',
                                'SLR'   => '(Metropolitana de Santiago)  LOS RULOS',
                                'ZXX'   => '(Metropolitana de Santiago)  LOYCA',
                                'MAC'   => '(Metropolitana de Santiago)  MACUL',
                                'MIP'   => '(Metropolitana de Santiago)  MAIPO',
                                'MAI'   => '(Metropolitana de Santiago)  MAIPU',
                                'MLL'   => '(Metropolitana de Santiago)  MALLOCO',
                                'SMD'   => '(Metropolitana de Santiago)  MANDINGA',
                                'MPO'   => '(Metropolitana de Santiago)  MARIA PINTO',
                                'ZMP'   => '(Metropolitana de Santiago)  MELIPILLA',
                                'NNA'   => '(Metropolitana de Santiago)  NUNOA',
                                'SPB'   => '(Metropolitana de Santiago)  PABELLON - MELIPILLA',
                                'PHT'   => '(Metropolitana de Santiago)  PADRE HURTADO',
                                'ZPN'   => '(Metropolitana de Santiago)  PAINE',
                                'PAC'   => '(Metropolitana de Santiago)  PEDRO AGUIRRE CERDA',
                                'PFL'   => '(Metropolitana de Santiago)  PENAFLOR',
                                'PNL'   => '(Metropolitana de Santiago)  PENALOLEN',
                                'SPT'   => '(Metropolitana de Santiago)  PINTUE',
                                'PIR'   => '(Metropolitana de Santiago)  PIRQUE',
                                'POL'   => '(Metropolitana de Santiago)  POLPAICO',
                                'IRE'   => '(Metropolitana de Santiago)  POMAIRE',
                                'PRO'   => '(Metropolitana de Santiago)  PROVIDENCIA',
                                'PUD'   => '(Metropolitana de Santiago)  PUDAHUEL',
                                'SPH'   => '(Metropolitana de Santiago)  PUEBLO HUNDIDO',
                                'PAL'   => '(Metropolitana de Santiago)  PUENTE ALTO',
                                'KPR'   => '(Metropolitana de Santiago)  PUNTA TORO',
                                'QLC'   => '(Metropolitana de Santiago)  QUILICURA',
                                'SQM'   => '(Metropolitana de Santiago)  QUIMCAHUE',
                                'QTN'   => '(Metropolitana de Santiago)  QUINTA NORMAL',
                                'ZUU'   => '(Metropolitana de Santiago)  RANGUE',
                                'RLT'   => '(Metropolitana de Santiago)  RECOLETA - SANTIAGO',
                                'REN'   => '(Metropolitana de Santiago)  RENCA',
                                'SAF'   => '(Metropolitana de Santiago)  SAN ALFONSO - STGO',
                                'SBD'   => '(Metropolitana de Santiago)  SAN BERNARDO',
                                'SGB'   => '(Metropolitana de Santiago)  SAN GABRIEL',
                                'SJQ'   => '(Metropolitana de Santiago)  SAN JOAQUIN',
                                'SJS'   => '(Metropolitana de Santiago)  SAN JOSE DE MAIPO',
                                'SMN'   => '(Metropolitana de Santiago)  SAN MANUEL',
                                'SMG'   => '(Metropolitana de Santiago)  SAN MIGUEL - STGO.',
                                'SPO'   => '(Metropolitana de Santiago)  SAN PEDRO - MELIPILL',
                                'SRN'   => '(Metropolitana de Santiago)  SAN RAMON',
                                'SIS'   => '(Metropolitana de Santiago)  SANTA INES',
                                'SMP'   => '(Metropolitana de Santiago)  SANTA MARTA - STGO',
                                'SCL'   => '(Metropolitana de Santiago)  SANTIAGO',
                                'TNT'   => '(Metropolitana de Santiago)  TALAGANTE',
                                'TIL'   => '(Metropolitana de Santiago)  TIL TIL',
                                'SVH'   => '(Metropolitana de Santiago)  VILLA ALHUE',
                                'SRV'   => '(Metropolitana de Santiago)  VILLA DEL VALLE',
                                'VTC'   => '(Metropolitana de Santiago)  VITACURA',
                                'AQB'   => '(Libertador General Bernardo O`Higgins)  AGUA BUENA',
                                'LNE'   => '(Libertador General Bernardo O`Higgins)  ALCONES',
                                'RAC'   => '(Libertador General Bernardo O`Higgins)  ALTO COLORADO',
                                'AQQ'   => '(Libertador General Bernardo O`Higgins)  AUQUINCO',
                                'BYY'   => '(Libertador General Bernardo O`Higgins)  BOYERUCA',
                                'PRM'   => '(Libertador General Bernardo O`Higgins)  BUCALEMU - RANCAGUA',
                                'RHL'   => '(Libertador General Bernardo O`Higgins)  CAHUIL',
                                'CTS'   => '(Libertador General Bernardo O`Higgins)  CALETONES',
                                'CRE'   => '(Libertador General Bernardo O`Higgins)  CERRILLOS',
                                'CHV'   => '(Libertador General Bernardo O`Higgins)  CHAPA VERDE',
                                'CHE'   => '(Libertador General Bernardo O`Higgins)  CHEPICA',
                                'CHB'   => '(Libertador General Bernardo O`Higgins)  CHIMBARONGO',
                                'RJC'   => '(Libertador General Bernardo O`Higgins)  CIRUELOS',
                                'CCN'   => '(Libertador General Bernardo O`Higgins)  COCALAN',
                                'ZDE'   => '(Libertador General Bernardo O`Higgins)  CODEGUA',
                                'CNO'   => '(Libertador General Bernardo O`Higgins)  COINCO - RANCAGUA',
                                'CLN'   => '(Libertador General Bernardo O`Higgins)  COLON',
                                'CTO'   => '(Libertador General Bernardo O`Higgins)  COLTAUCO',
                                'CVQ'   => '(Libertador General Bernardo O`Higgins)  CONVENTO VIEJO',
                                'KRC'   => '(Libertador General Bernardo O`Higgins)  CORNECHE',
                                'OCY'   => '(Libertador General Bernardo O`Higgins)  COYA',
                                'ZCU'   => '(Libertador General Bernardo O`Higgins)  CUNACO',
                                'DNE'   => '(Libertador General Bernardo O`Higgins)  DONIHUE',
                                'CAR'   => '(Libertador General Bernardo O`Higgins)  EL CARMEN',
                                'EGQ'   => '(Libertador General Bernardo O`Higgins)  EL GUAICO',
                                'MZN'   => '(Libertador General Bernardo O`Higgins)  EL MANZANO - RANCAGU',
                                'RPS'   => '(Libertador General Bernardo O`Higgins)  EL PUESTO',
                                'RET'   => '(Libertador General Bernardo O`Higgins)  EL TOCO',
                                'RZE'   => '(Libertador General Bernardo O`Higgins)  ESPERANZA',
                                'GRA'   => '(Libertador General Bernardo O`Higgins)  GRANEROS',
                                'HRQ'   => '(Libertador General Bernardo O`Higgins)  HACIENDA LOS LINGUES',
                                'HXO'   => '(Libertador General Bernardo O`Higgins)  HUEMUL',
                                'ZRW'   => '(Libertador General Bernardo O`Higgins)  LA BOCA - MELIPILLA',
                                'RLA'   => '(Libertador General Bernardo O`Higgins)  LA CEBADA',
                                'RLC'   => '(Libertador General Bernardo O`Higgins)  LA COMPANÍA - RANCAG',
                                'LAE'   => '(Libertador General Bernardo O`Higgins)  LA ESTRELLA',
                                'LLW'   => '(Libertador General Bernardo O`Higgins)  LA LAJUELA',
                                'LRW'   => '(Libertador General Bernardo O`Higgins)  LA LEONERA - RANCAGU',
                                'RLP'   => '(Libertador General Bernardo O`Higgins)  LA PUNTA',
                                'RQE'   => '(Libertador General Bernardo O`Higgins)  LA QUEBRADA - RANCAG',
                                'LRF'   => '(Libertador General Bernardo O`Higgins)  LA RUFINA',
                                'LQX'   => '(Libertador General Bernardo O`Higgins)  LARMAHUE',
                                'LCB'   => '(Libertador General Bernardo O`Higgins)  LAS CABRAS',
                                'KLD'   => '(Libertador General Bernardo O`Higgins)  LAS DAMAS',
                                'RLS'   => '(Libertador General Bernardo O`Higgins)  LAS NIEVES - RANCAGU',
                                'LPG'   => '(Libertador General Bernardo O`Higgins)  LAS PATAGUAS',
                                'LHX'   => '(Libertador General Bernardo O`Higgins)  LIHUEIMO',
                                'LTU'   => '(Libertador General Bernardo O`Higgins)  LITUECHE',
                                'LMI'   => '(Libertador General Bernardo O`Higgins)  LO MIRANDA',
                                'LVQ'   => '(Libertador General Bernardo O`Higgins)  LO VALDIVIA',
                                'LOL'   => '(Libertador General Bernardo O`Higgins)  LOLOL',
                                'RLM'   => '(Libertador General Bernardo O`Higgins)  LOS MAQUIS',
                                'MCH'   => '(Libertador General Bernardo O`Higgins)  MACHALI',
                                'ZML'   => '(Libertador General Bernardo O`Higgins)  MALLOA',
                                'RMT'   => '(Libertador General Bernardo O`Higgins)  MARCHANT',
                                'MRH'   => '(Libertador General Bernardo O`Higgins)  MARCHIHUE',
                                'KMT'   => '(Libertador General Bernardo O`Higgins)  MATANZAS',
                                'MLX'   => '(Libertador General Bernardo O`Higgins)  MILLAHUE',
                                'MJT'   => '(Libertador General Bernardo O`Higgins)  MINA LA JUANITA',
                                'MOX'   => '(Libertador General Bernardo O`Higgins)  MORZA',
                                'NGA'   => '(Libertador General Bernardo O`Higgins)  NANCAGUA',
                                'NAV'   => '(Libertador General Bernardo O`Higgins)  NAVIDAD',
                                'RNH'   => '(Libertador General Bernardo O`Higgins)  NERQUIHUE',
                                'RNI'   => '(Libertador General Bernardo O`Higgins)  NILAHUE',
                                'OAL'   => '(Libertador General Bernardo O`Higgins)  OLIVAR ALTO',
                                'ROL'   => '(Libertador General Bernardo O`Higgins)  OLIVAR BAJO',
                                'PLA'   => '(Libertador General Bernardo O`Higgins)  PALMILLA - RANCAGUA',
                                'PHU'   => '(Libertador General Bernardo O`Higgins)  PANIAHUE',
                                'PDS'   => '(Libertador General Bernardo O`Higgins)  PAREDONES',
                                'PEQ'   => '(Libertador General Bernardo O`Higgins)  PELEQUEN',
                                'ZPE'   => '(Libertador General Bernardo O`Higgins)  PERALILLO - RANCAGUA',
                                'PEO'   => '(Libertador General Bernardo O`Higgins)  PEUMO',
                                'PHA'   => '(Libertador General Bernardo O`Higgins)  PICHIDEGUA',
                                'PMU'   => '(Libertador General Bernardo O`Higgins)  PICHILEMU',
                                'RMC'   => '(Libertador General Bernardo O`Higgins)  PIMPINELA',
                                'PLL'   => '(Libertador General Bernardo O`Higgins)  PLACILLA - RANCAGUA',
                                'RQT'   => '(Libertador General Bernardo O`Higgins)  POBLACION',
                                'RPO'   => '(Libertador General Bernardo O`Higgins)  POPETA',
                                'RPT'   => '(Libertador General Bernardo O`Higgins)  PUENTE NEGRO',
                                'KPU'   => '(Libertador General Bernardo O`Higgins)  PUERTECILLO',
                                'PMQ'   => '(Libertador General Bernardo O`Higgins)  PUMANQUE',
                                'KPB'   => '(Libertador General Bernardo O`Higgins)  PUNTA BARRANCA',
                                'TPC'   => '(Libertador General Bernardo O`Higgins)  PUNTA DE CORTES',
                                'KPP'   => '(Libertador General Bernardo O`Higgins)  PUNTA PERRO',
                                'RPN'   => '(Libertador General Bernardo O`Higgins)  PUNTA VERDE',
                                'PRN'   => '(Libertador General Bernardo O`Higgins)  PUREN VI - RANCAGUA',
                                'QQW'   => '(Libertador General Bernardo O`Higgins)  QUINAHUE - CURICO',
                                'QPX'   => '(Libertador General Bernardo O`Higgins)  QUINTA',
                                'QCC'   => '(Libertador General Bernardo O`Higgins)  QUINTA DE TILCOCO',
                                'RCG'   => '(Libertador General Bernardo O`Higgins)  RANCAGUA',
                                'RQQ'   => '(Libertador General Bernardo O`Higgins)  RANGUIL',
                                'RPL'   => '(Libertador General Bernardo O`Higgins)  RAPEL - MELIPILLA',
                                'ZRG'   => '(Libertador General Bernardo O`Higgins)  RENGO',
                                'REQ'   => '(Libertador General Bernardo O`Higgins)  REQUINOA',
                                'RQY'   => '(Libertador General Bernardo O`Higgins)  RINCONADA DE YAQUIL',
                                'RMY'   => '(Libertador General Bernardo O`Higgins)  ROMA',
                                'RSS'   => '(Libertador General Bernardo O`Higgins)  ROSARIO',
                                'KSE'   => '(Libertador General Bernardo O`Higgins)  SAN ENRIQUE',
                                'SFM'   => '(Libertador General Bernardo O`Higgins)  SAN FCO DE MOSTAZAL',
                                'SFR'   => '(Libertador General Bernardo O`Higgins)  SAN FERNANDO',
                                'RSA'   => '(Libertador General Bernardo O`Higgins)  SAN JOSE MARCHIHUE',
                                'SPW'   => '(Libertador General Bernardo O`Higgins)  SAN PEDRO - RANCAGUA',
                                'KVP'   => '(Libertador General Bernardo O`Higgins)  SAN VICENTE DE PUCAL',
                                'SVT'   => '(Libertador General Bernardo O`Higgins)  SAN VICENTE DE T.T',
                                'ZSC'   => '(Libertador General Bernardo O`Higgins)  SANTA CRUZ',
                                'RGQ'   => '(Libertador General Bernardo O`Higgins)  SANTA GRACIELA ALCON',
                                'SEW'   => '(Libertador General Bernardo O`Higgins)  SEWELL',
                                'ZSB'   => '(Libertador General Bernardo O`Higgins)  SIERRA BELLAVISTA',
                                'RTE'   => '(Libertador General Bernardo O`Higgins)  TERMAS DE CAUQUENES',
                                'TZF'   => '(Libertador General Bernardo O`Higgins)  TERMAS DEL FLACO',
                                'TGR'   => '(Libertador General Bernardo O`Higgins)  TINGUIRIRICA',
                                'KTL'   => '(Libertador General Bernardo O`Higgins)  TOPOCALMA',
                                'TZT'   => '(Libertador General Bernardo O`Higgins)  TROMPETILLA',
                                'TZV'   => '(Libertador General Bernardo O`Higgins)  TUNCA ARRIBA',
                                'RZU'   => '(Libertador General Bernardo O`Higgins)  ZUNIGA',
                                'ADW'   => '(Maule)  ADUANA  ',
                                'ADJ'   => '(Maule)  ADUANA PEJERREY',
                                'JJZ'   => '(Maule)  AJIAL',
                                'ARB'   => '(Maule)  ARBOLILLO',
                                'BWP'   => '(Maule)  ARMERILLO',
                                'ZAS'   => '(Maule)  ASTILLERO',
                                'ZAU'   => '(Maule)  AURORA ',
                                'BYQ'   => '(Maule)  BARRERA',
                                'ZBA'   => '(Maule)  BATUCO - TALCA',
                                'ZBO'   => '(Maule)  BOTALCURA',
                                'LLZ'   => '(Maule)  BULLILLEO',
                                'CPQ'   => '(Maule)  CAMPAMENTO ANCOA',
                                'CQE'   => '(Maule)  CAUQUENES',
                                'CNC'   => '(Maule)  CHANCO',
                                'ZCP'   => '(Maule)  COIPUE',
                                'CLB'   => '(Maule)  COLBUN',
                                'ZCL'   => '(Maule)  COLIN',
                                'CTT'   => '(Maule)  CONSTITUCION',
                                'ZNM'   => '(Maule)  CORINTO',
                                'ZCS'   => '(Maule)  CORRALONES',
                                'XQP'   => '(Maule)  CULENAR',
                                'CUM'   => '(Maule)  CUMPEO',
                                'CNP'   => '(Maule)  CURANIPE',
                                'CUR'   => '(Maule)  CUREPTO',
                                'CCO'   => '(Maule)  CURICO',
                                'ZCE'   => '(Maule)  CURTIDURIA',
                                'UAO'   => '(Maule)  DUAO',
                                'ZEL'   => '(Maule)  EL COLORADO',
                                'XMM'   => '(Maule)  EL MANZANO - CURICO',
                                'PXQ'   => '(Maule)  EL PENON - TALCA',
                                'XPO'   => '(Maule)  EL PLANCHON',
                                'XSE'   => '(Maule)  EL SALTO',
                                'XTD'   => '(Maule)  EL TRANSITO - TALCA',
                                'EMP'   => '(Maule)  EMPEDRADO',
                                'ZED'   => '(Maule)  ENDESA ',
                                'ZGU'   => '(Maule)  GUALLECO',
                                'HNE'   => '(Maule)  HUALANE',
                                'XHR'   => '(Maule)  HUALVE',
                                'ILO'   => '(Maule)  ILOCA',
                                'ZIK'   => '(Maule)  ITAHUE',
                                'ZJU'   => '(Maule)  JUNQUILLAR',
                                'XLA'   => '(Maule)  LA LORA',
                                'ZLM'   => '(Maule)  LA MINA',
                                'LMN'   => '(Maule)  LA MONTANA',
                                'ZLT'   => '(Maule)  LA TRINCHERA',
                                'ZLJ'   => '(Maule)  LAS CAMPANAS',
                                'ZLG'   => '(Maule)  LAS GARZAS',
                                'LCT'   => '(Maule)  LICANTEN',
                                'LNR'   => '(Maule)  LINARES',
                                'ZVU'   => '(Maule)  LIPIMAVIDA',
                                'CUT'   => '(Maule)  LITU',
                                'XBL'   => '(Maule)  LLEPO',
                                'ZYC'   => '(Maule)  LLICO - CURICO',
                                'LGV'   => '(Maule)  LONGAVI',
                                'LTE'   => '(Maule)  LONTUE',
                                'XLY'   => '(Maule)  LOS CRISTALES',
                                'XNY'   => '(Maule)  LOS NABOS',
                                'LNH'   => '(Maule)  LOS NICHES',
                                'ZHH'   => '(Maule)  LOS PERALES',
                                'ZQX'   => '(Maule)  LOS QUENES',
                                'XRX'   => '(Maule)  LOS RABONES',
                                'ZMA'   => '(Maule)  MAULE',
                                'XMK'   => '(Maule)  MELADO',
                                'ZMG'   => '(Maule)  MELAO',
                                'XMD'   => '(Maule)  MELOZAL',
                                'XME'   => '(Maule)  MESAMAVIDA',
                                'ZMI'   => '(Maule)  MIRAFLORES - TALCA',
                                'ZMO'   => '(Maule)  MOLINA',
                                'ZPA'   => '(Maule)  MONTE OSCURO',
                                'ZNI'   => '(Maule)  NIRIVILO',
                                'XPE'   => '(Maule)  PALMILLA',
                                'XQB'   => '(Maule)  PALQUIBUDA',
                                'PNV'   => '(Maule)  PANIMAVIDA',
                                'PRR'   => '(Maule)  PARRAL',
                                'XEI'   => '(Maule)  PASO HONDO - TALCA',
                                'XPS'   => '(Maule)  PASO NEVADO',
                                'PLC'   => '(Maule)  PELARCO',
                                'PEL'   => '(Maule)  PELLUHUE',
                                'PEH'   => '(Maule)  PENCAHUE',
                                'PQQ'   => '(Maule)  PERQUILAUQUEN',
                                'ZKQ'   => '(Maule)  PICHAMAN',
                                'BCH'   => '(Maule)  PICHIBUDI',
                                'PTG'   => '(Maule)  POTRERO GRANDE',
                                'XPC'   => '(Maule)  POTRERO GRANDE CHICO',
                                'PUU'   => '(Maule)  PUTU',
                                'ZQH'   => '(Maule)  QUEBRADA HONDA',
                                'XQL'   => '(Maule)  QUELLA',
                                'QQH'   => '(Maule)  QUINCHIMAVIDA',
                                'ZQV'   => '(Maule)  QUINMAVIDA',
                                'ZQI'   => '(Maule)  QUIVOLGO',
                                'XXR'   => '(Maule)  RADAL - CURICO',
                                'RAU'   => '(Maule)  RAUCO',
                                'ZRB'   => '(Maule)  REBECA',
                                'RTR'   => '(Maule)  RETIRO - TALCA',
                                'RCL'   => '(Maule)  RIO CLARO - TALCA',
                                'XRI'   => '(Maule)  ROBLERIA',
                                'RML'   => '(Maule)  ROMERAL',
                                'SFA'   => '(Maule)  SAGRADA FAMILIA',
                                'STE'   => '(Maule)  SAN CLEMENTE',
                                'SJA'   => '(Maule)  SAN JAVIER',
                                'SZS'   => '(Maule)  SAN PABLO',
                                'SRF'   => '(Maule)  SAN RAFAEL',
                                'ZSN'   => '(Maule)  SANTA ANA',
                                'ZCA'   => '(Maule)  TALCA',
                                'TEN'   => '(Maule)  TENO',
                                'TQC'   => '(Maule)  TERMAS DE CATILLO',
                                'SAR'   => '(Maule)  TRINCAO - CURICO',
                                'ZUV'   => '(Maule)  UNICAVEN',
                                'ZUO'   => '(Maule)  UPEO',
                                'VCH'   => '(Maule)  VICHUQUEN',
                                'VGE'   => '(Maule)  VILLA ALEGRE - TALCA',
                                'ZVO'   => '(Maule)  VILLA PRAT',
                                'VZQ'   => '(Maule)  VILLA ROSAS',
                                'ZVS'   => '(Maule)  VILLA SECA',
                                'XYY'   => '(Maule)  YACEL',
                                'YBB'   => '(Maule)  YERBAS BUENAS',
                                'YBU'   => '(Ñuble)  BUCHUPUREO',
                                'BLN'   => '(Ñuble)  BULNES',
                                'YCA'   => '(Ñuble)  CACHAPOAL - CHILLAN',
                                'YCM'   => '(Ñuble)  CAMPANARIO',
                                'YCN'   => '(Ñuble)  CANCHA ALEGRE',
                                'YAI'   => '(Ñuble)  CHILLAN',
                                'YAV'   => '(Ñuble)  CHILLAN VIEJO',
                                'YCH'   => '(Ñuble)  CHOLGUAN',
                                'CQU'   => '(Ñuble)  COBQUECURA',
                                'ZOU'   => '(Ñuble)  COELEMU',
                                'CUH'   => '(Ñuble)  COIHUECO',
                                'YCO'   => '(Ñuble)  COIPIN',
                                'YCL'   => '(Ñuble)  COLMUYAO',
                                'ZIR'   => '(Ñuble)  CONAIR',
                                'YCF'   => '(Ñuble)  CONFLUENCIA',
                                'YCX'   => '(Ñuble)  EL CARMEN - CHILLAN',
                                'YEL'   => '(Ñuble)  EL PARRON',
                                'YEY'   => '(Ñuble)  EL SALTILLO',
                                'YES'   => '(Ñuble)  EL SAUCE',
                                'FRQ'   => '(Ñuble)  FUNDO LOS ROBLES',
                                'YGE'   => '(Ñuble)  GENERAL CRUZ',
                                'LQP'   => '(Ñuble)  LA CAPILLA - CHILLAN',
                                'YLA'   => '(Ñuble)  LA PUNTILLA',
                                'YLS'   => '(Ñuble)  LAS TRANCAS',
                                'YLO'   => '(Ñuble)  LOS CASTANOS',
                                'YLP'   => '(Ñuble)  LOS PUQUIOS',
                                'YME'   => '(Ñuble)  MELA',
                                'MPD'   => '(Ñuble)  MINAS DEL PRADO',
                                'YNA'   => '(Ñuble)  NAHUELTORO',
                                'NIN'   => '(Ñuble)  NINHUE',
                                'ZNY'   => '(Ñuble)  NIPAS',
                                'NYY'   => '(Ñuble)  NIQUEN',
                                'ZNA'   => '(Ñuble)  NUEVA ALDEA',
                                'ZPP'   => '(Ñuble)  PANGAL - LOS ANGELES',
                                'ZPC'   => '(Ñuble)  PEMUCO',
                                'PNO'   => '(Ñuble)  PINTO',
                                'YPO'   => '(Ñuble)  POCILLAS',
                                '49H'   => '(Ñuble)  PORTEZUELO',
                                'YPU'   => '(Ñuble)  PUEBLO SECO',
                                'YPL'   => '(Ñuble)  PULLAY',
                                'QLL'   => '(Ñuble)  QUILLON',
                                'QML'   => '(Ñuble)  QUINCHAMALI',
                                'QIH'   => '(Ñuble)  QUIRIHUE',
                                'QNA'   => '(Ñuble)  QUIRIQUINA',
                                'RNQ'   => '(Ñuble)  RANQUIL',
                                'ZER'   => '(Ñuble)  RAQUIL',
                                'YRE'   => '(Ñuble)  RECINTO',
                                'YRU'   => '(Ñuble)  RUCAPEQUEN',
                                'SCS'   => '(Ñuble)  SAN CARLOS - CHILLAN',
                                'SFB'   => '(Ñuble)  SAN FABIAN DE ALICO',
                                'YSN'   => '(Ñuble)  SAN GREGORIO NIQUEN ',
                                'SIG'   => '(Ñuble)  SAN IGNACIO - CHILLA',
                                'ZCG'   => '(Ñuble)  SAN IGNACIO - CONCEP',
                                'SMW'   => '(Ñuble)  SAN MIGUEL',
                                'SNL'   => '(Ñuble)  SAN NICOLAS',
                                'SQZ'   => '(Ñuble)  SAN PEDRO - CHILLAN',
                                'YTA'   => '(Ñuble)  TANILVORO',
                                'YTE'   => '(Ñuble)  TERMAS DE CHILLAN',
                                'YTR'   => '(Ñuble)  TORRECILLA',
                                'YTG'   => '(Ñuble)  TREGUACO',
                                'YTU'   => '(Ñuble)  TREGUALEMU',
                                'TRH'   => '(Ñuble)  TREHUACO',
                                'YGY'   => '(Ñuble)  YUNGAY',
                                'ZAY'   => '(Ñuble)  ZAPALLAR - CHILLAN',
                                'YZE'   => '(Ñuble)  ZEMITA',
                                'ZGG'   => '(Bío - Bío)  AGUAS DE LA GLORIA',
                                'AOO'   => '(Bío - Bío)  ALTO BIO BIO',
                                'ANI'   => '(Bío - Bío)  ALTO CALEDONIA',
                                'ZNT'   => '(Bío - Bío)  ANTIGUALA',
                                'ZQG'   => '(Bío - Bío)  ANTIQUINA',
                                'ANT'   => '(Bío - Bío)  ANTUCO',
                                'ARA'   => '(Bío - Bío)  ARAUCO',
                                'LBQ'   => '(Bío - Bío)  BUENURAQUI',
                                'CRO'   => '(Bío - Bío)  CABRERO',
                                'CTE'   => '(Bío - Bío)  CANETE',
                                'CRA'   => '(Bío - Bío)  CANICURA',
                                'CNT'   => '(Bío - Bío)  CANTERAS',
                                'PAN'   => '(Bío - Bío)  CARAMPANGUE',
                                'ZOT'   => '(Bío - Bío)  CASA LOLCO',
                                'ZZW'   => '(Bío - Bío)  CAYUCUPIL',
                                'LCP'   => '(Bío - Bío)  CERRO DEL PADRE',
                                'CYE'   => '(Bío - Bío)  CHIGUAYANTE',
                                'CIO'   => '(Bío - Bío)  CHOROICO',
                                'LCE'   => '(Bío - Bío)  COIHUE',
                                'LCI'   => '(Bío - Bío)  COLONIA',
                                'ZRI'   => '(Bío - Bío)  COMUNIDAD CANICU',
                                'CCP'   => '(Bío - Bío)  CONCEPCION',
                                'CTU'   => '(Bío - Bío)  CONTULMO',
                                'ZUM'   => '(Bío - Bío)  COPIULEMU',
                                'CRN'   => '(Bío - Bío)  CORONEL',
                                'MLC'   => '(Bío - Bío)  CURACO - CONCEPCION',
                                'ZHE'   => '(Bío - Bío)  CURANILAHUE',
                                'DTO'   => '(Bío - Bío)  DICHATO',
                                'LDQ'   => '(Bío - Bío)  DIUQUIN',
                                'LEA'   => '(Bío - Bío)  EL ABANICO',
                                'LEL'   => '(Bío - Bío)  EL ALAMO',
                                'LEV'   => '(Bío - Bío)  EL AVELLANO',
                                'ZBC'   => '(Bío - Bío)  EL BOLDO',
                                'LGH'   => '(Bío - Bío)  EL GUACHI',
                                'LMR'   => '(Bío - Bío)  EL MORRO',
                                'LTW'   => '(Bío - Bío)  EL TORO',
                                'EYY'   => '(Bío - Bío)  ESTACION YUMBEL',
                                'FLO'   => '(Bío - Bío)  FLORIDA',
                                'HLP'   => '(Bío - Bío)  HUALPEN',
                                'HLQ'   => '(Bío - Bío)  HUALQUI',
                                'HUP'   => '(Bío - Bío)  HUEPIL',
                                'IQR'   => '(Bío - Bío)  ISLA QUIRIQUINA',
                                'ZBB'   => '(Bío - Bío)  LA BOCA - CONCEPCION',
                                'LLJ'   => '(Bío - Bío)  LAJA',
                                'LAQ'   => '(Bío - Bío)  LARAQUETE',
                                'LNV'   => '(Bío - Bío)  LAS NIEVES',
                                'ZLB'   => '(Bío - Bío)  LEBU',
                                'LIR'   => '(Bío - Bío)  LIRQUEN',
                                'YCU'   => '(Bío - Bío)  LIUCURA',
                                'ZCF'   => '(Bío - Bío)  LLICO - CONCEPCION',
                                'COC'   => '(Bío - Bío)  LOLCO',
                                'LGE'   => '(Bío - Bío)  LONCOPANGUE',
                                'LAL'   => '(Bío - Bío)  LOS ALAMOS',
                                'LSQ'   => '(Bío - Bío)  LOS ANGELES',
                                'LLB'   => '(Bío - Bío)  LOS BARROS',
                                'LBS'   => '(Bío - Bío)  LOS BRUJOS',
                                'LZX'   => '(Bío - Bío)  LOS MAICAS',
                                'LBO'   => '(Bío - Bío)  LOS PLACERES',
                                'LOT'   => '(Bío - Bío)  LOTA',
                                'LLM'   => '(Bío - Bío)  MAITENES',
                                'MEA'   => '(Bío - Bío)  MELICA',
                                'ZQW'   => '(Bío - Bío)  MENQUE',
                                'ZNG'   => '(Bío - Bío)  MILLONHUE',
                                'ZLA'   => '(Bío - Bío)  MONTE AGUILA',
                                'MUL'   => '(Bío - Bío)  MULCHEN',
                                'NAC'   => '(Bío - Bío)  NACIMIENTO',
                                'NRE'   => '(Bío - Bío)  NEGRETE',
                                'PLO'   => '(Bío - Bío)  PAILACO',
                                'ZLL'   => '(Bío - Bío)  PANGUE',
                                'PHY'   => '(Bío - Bío)  PASO HONDO',
                                'YCR'   => '(Bío - Bío)  PASO HONDO - CHILLAN',
                                'ZPQ'   => '(Bío - Bío)  PEHUEN',
                                'PCO'   => '(Bío - Bío)  PENCO',
                                'ZWP'   => '(Bío - Bío)  PILPILCO',
                                'LPO'   => '(Bío - Bío)  POLCURA',
                                'PGS'   => '(Bío - Bío)  PROGRESO',
                                'ZQR'   => '(Bío - Bío)  QUIDICO - CONCEPCION',
                                'ZDQ'   => '(Bío - Bío)  QUIDICO - TEMUCO',
                                'QCO'   => '(Bío - Bío)  QUILACO',
                                'ZIQ'   => '(Bío - Bío)  QUILACOYA',
                                'QLO'   => '(Bío - Bío)  QUILLECO',
                                'ZQA'   => '(Bío - Bío)  QUINAHUE - CONCEPCIO',
                                'ZRA'   => '(Bío - Bío)  RAFAEL',
                                'RCO'   => '(Bío - Bío)  RALCO',
                                'ZLN'   => '(Bío - Bío)  RALCO LEPOY',
                                'ZMD'   => '(Bío - Bío)  RAMADILLA',
                                'RTH'   => '(Bío - Bío)  RANCHO TALCAHUANO',
                                'GUO'   => '(Bío - Bío)  RANGUELMO',
                                'ZRQ'   => '(Bío - Bío)  RANQUILCO',
                                'ZUQ'   => '(Bío - Bío)  RAQUI',
                                'RIE'   => '(Bío - Bío)  RIHUE',
                                'ZWE'   => '(Bío - Bío)  RINCONADA - CONCEPCI',
                                'LRC'   => '(Bío - Bío)  RIO CLARO - LOS ANGE',
                                'ZRO'   => '(Bío - Bío)  ROA',
                                'LRH'   => '(Bío - Bío)  RUCALHUE',
                                'ZYR'   => '(Bío - Bío)  RUCARAQUIL',
                                'CFF'   => '(Bío - Bío)  SAN ALFONSO - CONCEP',
                                'SCP'   => '(Bío - Bío)  SAN CARLOS PUREN - L',
                                'SCW'   => '(Bío - Bío)  SAN CARLOS PUREN - L',
                                'SJL'   => '(Bío - Bío)  SAN JOSE DE COLICO',
                                'LSM'   => '(Bío - Bío)  SAN MIGUEL',
                                'SPP'   => '(Bío - Bío)  SAN PEDRO DE LA PAZ',
                                'SRO'   => '(Bío - Bío)  SAN ROSENDO',
                                'SVC'   => '(Bío - Bío)  SAN VICENTE ( CONCEP. )',
                                'SBB'   => '(Bío - Bío)  SANTA BARBARA',
                                'CLA'   => '(Bío - Bío)  SANTA CLARA',
                                'LST'   => '(Bío - Bío)  SANTA CLARA',
                                'LSF'   => '(Bío - Bío)  SANTA FE',
                                'SJN'   => '(Bío - Bío)  SANTA JUANA',
                                'ZBL'   => '(Bío - Bío)  SARA DE LEBU',
                                'ZTO'   => '(Bío - Bío)  TALCAHUANO',
                                'CTV'   => '(Bío - Bío)  TALCAMAVIDA',
                                'ZTV'   => '(Bío - Bío)  TERMAS DEL AVELLANO',
                                'TUA'   => '(Bío - Bío)  TIRUA',
                                'TMC'   => '(Bío - Bío)  TOME',
                                'TMK'   => '(Bío - Bío)  TOMECO',
                                'ZTP'   => '(Bío - Bío)  TRES PINOS',
                                'LTP'   => '(Bío - Bío)  TRUPAN',
                                'TCP'   => '(Bío - Bío)  TUCAPEL',
                                'ZTT'   => '(Bío - Bío)  VEGAS DE ITATA',
                                'VAG'   => '(Bío - Bío)  VILLA ALEGRE - CONCE',
                                'LVM'   => '(Bío - Bío)  VILLA MERCEDES',
                                'LVU'   => '(Bío - Bío)  VILLUCURA',
                                'ZYY'   => '(Bío - Bío)  YENECO',
                                'ZYU'   => '(Bío - Bío)  YUMBEL',
                                'AST'   => '(Araucanía)  AGUA SANTA',
                                'ZGV'   => '(Araucanía)  ALMAGRO',
                                'ZOL'   => '(Araucanía)  ANGOL',
                                'ZBR'   => '(Araucanía)  BARROS ARANA',
                                'BBD'   => '(Araucanía)  BOCA BUDI',
                                'BOA'   => '(Araucanía)  BOROA',
                                'ZCB'   => '(Araucanía)  CABURGUA',
                                'CJN'   => '(Araucanía)  CAJON',
                                'VAC'   => '(Araucanía)  CAMARONES - TEMUCO',
                                'CDA'   => '(Araucanía)  CANADA',
                                'CPP'   => '(Araucanía)  CAPITAN PASTENE',
                                'CRH'   => '(Araucanía)  CARAHUE',
                                'ZCT'   => '(Araucanía)  CENTENARIO',
                                'ZCC'   => '(Araucanía)  CHERQUENCO',
                                'CHL'   => '(Araucanía)  CHOLCHOL',
                                'CPI'   => '(Araucanía)  COLLIPULLI',
                                'CLU'   => '(Araucanía)  COLONIA LAUTARO',
                                'ZCM'   => '(Araucanía)  COMUY',
                                'CRS'   => '(Araucanía)  CRUCES',
                                'NCO'   => '(Araucanía)  CUNCO',
                                'CCC'   => '(Araucanía)  CURACAUTIN',
                                'HDF'   => '(Araucanía)  CURACO ',
                                'RRH'   => '(Araucanía)  CURARREHUE',
                                'ZEA'   => '(Araucanía)  EL ALAMBRADO',
                                'EAG'   => '(Araucanía)  EL AMARGO',
                                'ERL'   => '(Araucanía)  ERCILLA',
                                'FIE'   => '(Araucanía)  FREIRE',
                                'GAL'   => '(Araucanía)  GALVARINO',
                                'ZGE'   => '(Araucanía)  GENERAL LOPEZ',
                                'GEA'   => '(Araucanía)  GORBEA',
                                'ZHL'   => '(Araucanía)  HELO SUR',
                                'UAL'   => '(Araucanía)  HUALPIN',
                                'ZTZ'   => '(Araucanía)  HUIFE',
                                'ZHS'   => '(Araucanía)  HUISCAPI',
                                'ZIC'   => '(Araucanía)  ICALMA',
                                'ZBN'   => '(Araucanía)  LA SOMBRA',
                                'LZA'   => '(Araucanía)  LABRANZA',
                                'ZLH'   => '(Araucanía)  LAS HORTENCIAS',
                                'ZJM'   => '(Araucanía)  LAS MARIPOSAS - TEMU',
                                'ZLR'   => '(Araucanía)  LASTARRIA',
                                'LTR'   => '(Araucanía)  LAUTARO',
                                'IRA'   => '(Araucanía)  LIUCURA - TEMUCO',
                                'ZLE'   => '(Araucanía)  LOBERIA',
                                'LLN'   => '(Araucanía)  LOLEN',
                                'LLE'   => '(Araucanía)  LOLENCO',
                                'ZLV'   => '(Araucanía)  LOMACURA',
                                'LOC'   => '(Araucanía)  LONCOCHE',
                                'LQY'   => '(Araucanía)  LONQUIMAY',
                                'ZSO'   => '(Araucanía)  LOS LAURELES',
                                'ZLD'   => '(Araucanía)  LOS PRADOS',
                                'SUS'   => '(Araucanía)  LOS SAUCES',
                                'LUM'   => '(Araucanía)  LUMACO',
                                'LLH'   => '(Araucanía)  MAITENREHUE',
                                'ZOH'   => '(Araucanía)  MALALCAHUELO ',
                                'ZMN'   => '(Araucanía)  MANZANAR',
                                'MQH'   => '(Araucanía)  MAQUEHUE',
                                'MLP'   => '(Araucanía)  MELIPEUCO',
                                'MTR'   => '(Araucanía)  METRENCO',
                                'MNC'   => '(Araucanía)  MININCO',
                                'MBA'   => '(Araucanía)  MISION BOROA',
                                'NNH'   => '(Araucanía)  NAHUELVE',
                                'LYY'   => '(Araucanía)  NANCO',
                                'ZNH'   => '(Araucanía)  NEHUENTUE',
                                'NIP'   => '(Araucanía)  NUEVA IMPERIAL',
                                'PCS'   => '(Araucanía)  PADRE LAS CASAS',
                                'ZPH'   => '(Araucanía)  PAILAHUENQUE',
                                'ZPD'   => '(Araucanía)  PEDREGOSO',
                                'PEC'   => '(Araucanía)  PELECO',
                                'ZPC'   => '(Araucanía)  PEMUCO',
                                'PQO'   => '(Araucanía)  PERQUENCO',
                                'ZNN'   => '(Araucanía)  PICHIPELLAHUEN',
                                'PDA'   => '(Araucanía)  PIEDRA DEL AGUILA',
                                'ZUN'   => '(Araucanía)  PILLANLELBUN',
                                'PQN'   => '(Araucanía)  PITRUFQUEN',
                                'MFN'   => '(Araucanía)  PLAYA NEGRA',
                                'ZPB'   => '(Araucanía)  PORVENIR',
                                'CAU'   => '(Araucanía)  PUA',
                                'ZPU'   => '(Araucanía)  PUCON',
                                'ZPM'   => '(Araucanía)  PUERTO DOMINGUEZ',
                                'PPM'   => '(Araucanía)  PUERTO PUMA',
                                'ZPS'   => '(Araucanía)  PUERTO SAAVEDRA',
                                'PUE'   => '(Araucanía)  PUESCO',
                                'PUR'   => '(Araucanía)  PUREN - TEMUCO',
                                'ZQE'   => '(Araucanía)  QUECHEREGUAS',
                                'QUP'   => '(Araucanía)  QUEPE',
                                'ZQL'   => '(Araucanía)  QUILQUE',
                                'ZQN'   => '(Araucanía)  QUINQUEN',
                                'ZQT'   => '(Araucanía)  QUITRATUE',
                                'ZLK'   => '(Araucanía)  RADAL - TEMUCO',
                                'ZRE'   => '(Araucanía)  REFUGIO',
                                'ZRF'   => '(Araucanía)  REFUGIO LLAIMA',
                                'ZGO'   => '(Araucanía)  REIGOLIL',
                                'ZRL'   => '(Araucanía)  RELUN',
                                'RNA'   => '(Araucanía)  RENAICO',
                                'ZRT'   => '(Araucanía)  RETEN DOLLINCO',
                                'ZXR'   => '(Araucanía)  RUCATRARO',
                                'ZSP'   => '(Araucanía)  SAN PATRICIO',
                                'SSP'   => '(Araucanía)  SAN PEDRO - TEMUCO',
                                'SZZ'   => '(Araucanía)  SANTA ROSA - TEMUCO',
                                'SSO'   => '(Araucanía)  SELVA OSCURA',
                                'ZSI'   => '(Araucanía)  SIERRA NEVADA',
                                'ZCO'   => '(Araucanía)  TEMUCO',
                                'TEO'   => '(Araucanía)  TEODORO SCHMIDT',
                                'ZTR'   => '(Araucanía)  TERMAS DE HUIFE',
                                'ZMT'   => '(Araucanía)  TERMAS DE MENETUE',
                                'ZMY'   => '(Araucanía)  TERMAS DE MOLULCO',
                                'ZTM'   => '(Araucanía)  TERMAS DE PALGUIN',
                                'GAR'   => '(Araucanía)  TERMAS DE PANGUI',
                                'MTW'   => '(Araucanía)  TERMAS DE PEMEHUE',
                                'ZTS'   => '(Araucanía)  TERMAS DE RIO BLANCO',
                                'TSL'   => '(Araucanía)  TERMAS DE SAN LUIS',
                                'ZTB'   => '(Araucanía)  TERMAS DE SAN SEBAST',
                                'ZTD'   => '(Araucanía)  TERMAS DE TOLHUACA',
                                'LTJ'   => '(Araucanía)  TIJERAL',
                                'TOL'   => '(Araucanía)  TOLTEN',
                                'ZEN'   => '(Araucanía)  TRAIGUEN',
                                'ZTQ'   => '(Araucanía)  TRES ESQUINAS',
                                'TTE'   => '(Araucanía)  TRINTRE',
                                'ZTK'   => '(Araucanía)  TROVOLHUE',
                                'ZTY'   => '(Araucanía)  TROYO',
                                'LVB'   => '(Araucanía)  VEGAS BLANCAS',
                                'VIC'   => '(Araucanía)  VICTORIA',
                                'VIL'   => '(Araucanía)  VILCUN',
                                'VZA'   => '(Araucanía)  VILLA ARAUCANIA',
                                'VRR'   => '(Araucanía)  VILLARRICA',
                                'ANH'   => '(Los Ríos)  ANTILHUE',
                                'ZBZ'   => '(Los Ríos)  BANOS DE CHIHUIO',
                                'ZCZ'   => '(Los Ríos)  CALAFQUEN',
                                'ZZQ'   => '(Los Ríos)  CARIRRINGUE',
                                'ZCY'   => '(Los Ríos)  CAYURRUCA',
                                'ZXB'   => '(Los Ríos)  CHABRANCO',
                                'ZNX'   => '(Los Ríos)  CHANCHAN',
                                'ZAX'   => '(Los Ríos)  CHANCOYAN',
                                'CHS'   => '(Los Ríos)  CHOSHUENCO',
                                'ZCI'   => '(Los Ríos)  CIRUELOS - VALDIVIA',
                                'COI'   => '(Los Ríos)  COIQUE',
                                'COA'   => '(Los Ríos)  COLEGUAL - VALDIVIA',
                                'CPE'   => '(Los Ríos)  CONARIPE',
                                'ZCR'   => '(Los Ríos)  CORRAL',
                                'CNA'   => '(Los Ríos)  CURINANCO',
                                'ZDO'   => '(Los Ríos)  DOLLINCO',
                                'ORO'   => '(Los Ríos)  EL MIRADOR',
                                'EMN'   => '(Los Ríos)  EL MUNDIAL',
                                'ZNC'   => '(Los Ríos)  ENCO',
                                'ZFO'   => '(Los Ríos)  FOLILCO',
                                'ZFF'   => '(Los Ríos)  FUERTE SAN LUIS',
                                'FAE'   => '(Los Ríos)  FUNDO ALTUE',
                                'FTR'   => '(Los Ríos)  FUTRONO',
                                'ZHC'   => '(Los Ríos)  HUEICOLLA',
                                'ZHU'   => '(Los Ríos)  HUEQUECURA',
                                'ZYH'   => '(Los Ríos)  HUEYELHUE',
                                'HIC'   => '(Los Ríos)  HUICHACO',
                                'ZHI'   => '(Los Ríos)  HUITE',
                                'ZIG'   => '(Los Ríos)  IGNAO',
                                'ZEQ'   => '(Los Ríos)  ILIHUE',
                                'OAA'   => '(Los Ríos)  LA BARRA',
                                'ZLW'   => '(Los Ríos)  LA CAPILLA - VALDIV',
                                'LRA'   => '(Los Ríos)  LA LEONERA - VALDIVI',
                                'ZLP'   => '(Los Ríos)  LA PENA',
                                'ZLU'   => '(Los Ríos)  LA UNION',
                                'LRO'   => '(Los Ríos)  LAGO RANCO',
                                'LNC'   => '(Los Ríos)  LANCO',
                                'LVS'   => '(Los Ríos)  LAS VENTANAS',
                                'LCY'   => '(Los Ríos)  LICAN RAY',
                                'OSN'   => '(Los Ríos)  LIPINGUE',
                                'ZVC'   => '(Los Ríos)  LIQUINE',
                                'LLI'   => '(Los Ríos)  LLIFEN',
                                'OEU'   => '(Los Ríos)  LLIHUE',
                                'LCL'   => '(Los Ríos)  LOS CHILCOS',
                                'ZAQ'   => '(Los Ríos)  LOS CONALES - OSORNO',
                                'OSE'   => '(Los Ríos)  LOS CONALES - OSORNO',
                                'LAG'   => '(Los Ríos)  LOS LAGOS',
                                'ZLO'   => '(Los Ríos)  LOS LLOLLES',
                                'LML'   => '(Los Ríos)  LOS MOLINOS',
                                'LPS'   => '(Los Ríos)  LOS PELLINES - VALDI',
                                'ZLS'   => '(Los Ríos)  LOS TALLOS',
                                'ZLX'   => '(Los Ríos)  LOS ULMOS',
                                'MFL'   => '(Los Ríos)  MAFIL',
                                'MLE'   => '(Los Ríos)  MAIHUE',
                                'MAL'   => '(Los Ríos)  MALALHUE',
                                'MMO'   => '(Los Ríos)  MANAO - VALDIVIA',
                                'MEH'   => '(Los Ríos)  MEHUIN',
                                'ZMB'   => '(Los Ríos)  MONTUELA',
                                'NCU'   => '(Los Ríos)  NANCUL',
                                'NTM'   => '(Los Ríos)  NELTUME',
                                'NBL'   => '(Los Ríos)  NIEBLA',
                                'PAI'   => '(Los Ríos)  PAILLACO',
                                'PGP'   => '(Los Ríos)  PANGUIPULLI',
                                'ZPI'   => '(Los Ríos)  PICHIRROPULLI',
                                'CHY'   => '(Los Ríos)  PICHOY',
                                'ZPX'   => '(Los Ríos)  PUCARA',
                                'PUC'   => '(Los Ríos)  PUCONO',
                                'ZFQ'   => '(Los Ríos)  PUERTO FUY',
                                'ZXN'   => '(Los Ríos)  PUERTO NUEVO',
                                'ZAE'   => '(Los Ríos)  PUERTO PAICO',
                                'ZPT'   => '(Los Ríos)  PUERTO PIRIHUEICO',
                                'PGE'   => '(Los Ríos)  PULLINGUE',
                                'PTC'   => '(Los Ríos)  PUNTA CHAIHUIN',
                                'NUC'   => '(Los Ríos)  PUNUCAPA',
                                'ZPG'   => '(Los Ríos)  PURINGUE',
                                'ZPO'   => '(Los Ríos)  PURULON',
                                'ZQU'   => '(Los Ríos)  QUEULE - VALDIVIA',
                                'ZRP'   => '(Los Ríos)  RAPACO',
                                'RMN'   => '(Los Ríos)  REUMEN',
                                'XGR'   => '(Los Ríos)  RINIHUE',
                                'ZZR'   => '(Los Ríos)  RININAHUE',
                                'RBN'   => '(Los Ríos)  RIO BUENO',
                                'ZRU'   => '(Los Ríos)  RUNCA',
                                'MQA'   => '(Los Ríos)  S.J. DE LA MARIQUINA',
                                'ZSA'   => '(Los Ríos)  SALTO DEL AGUA',
                                'ZSS'   => '(Los Ríos)  SANTA ELISA',
                                'ZSR'   => '(Los Ríos)  SANTA ROSA - OSORNO',
                                'TRC'   => '(Los Ríos)  TERMAS DE CONARIPE',
                                'TRR'   => '(Los Ríos)  TRAITRACO',
                                'ZAP'   => '(Los Ríos)  TRALCAO',
                                'OIP'   => '(Los Ríos)  TRAPI',
                                'ODA'   => '(Los Ríos)  TRINIDAD',
                                'TMA'   => '(Los Ríos)  TRUMAO',
                                'ZAL'   => '(Los Ríos)  VALDIVIA',
                                'ZVV'   => '(Los Ríos)  VIVANCO',
                                'PAB'   => '(Los Lagos)  ABTAO',
                                'ZAO'   => '(Los Lagos)  ACHAO',
                                'PZG'   => '(Los Lagos)  AGUAS  BUENAS',
                                'ZAA'   => '(Los Lagos)  AGUAS CALIENTES - OS',
                                'AHI'   => '(Los Lagos)  AHONI',
                                'PWU'   => '(Los Lagos)  AITUI',
                                'ADO'   => '(Los Lagos)  ALDACHILDO',
                                'ALE'   => '(Los Lagos)  ALERCE',
                                'PAT'   => '(Los Lagos)  ALTO BUTALCURA',
                                'ACD'   => '(Los Lagos)  ANCUD',
                                'ZAC'   => '(Los Lagos)  ANTICURA',
                                'APO'   => '(Los Lagos)  APIAO',
                                'PAU'   => '(Los Lagos)  AUCAR',
                                'ALN'   => '(Los Lagos)  AULEN',
                                'PAY'   => '(Los Lagos)  AYACARA',
                                'ZBH'   => '(Los Lagos)  BAHIA MANSA',
                                'PBS'   => '(Los Lagos)  BANOS DE SOTOMO',
                                'PZB'   => '(Los Lagos)  BELBEN',
                                'PBX'   => '(Los Lagos)  BUILL',
                                'CBU'   => '(Los Lagos)  CALBUCO',
                                'PCG'   => '(Los Lagos)  CALETA GONZALO',
                                'PWX'   => '(Los Lagos)  CALETA HUALAIHUE',
                                'PCA'   => '(Los Lagos)  CALETA LA ARENA',
                                'PBB'   => '(Los Lagos)  CALETA SANTA BARBARA',
                                'OAR'   => '(Los Lagos)  CANCURA',
                                'PWC'   => '(Los Lagos)  CANUTILLAR',
                                'OLO'   => '(Los Lagos)  CARACOL',
                                'CRU'   => '(Los Lagos)  CARELMAPU',
                                'OAM'   => '(Los Lagos)  CASMA',
                                'CTR'   => '(Los Lagos)  CASTRO',
                                'CHG'   => '(Los Lagos)  CAULIN',
                                'OOC'   => '(Los Lagos)  CENTRAL RUPANCO',
                                'CAO'   => '(Los Lagos)  CHACAO',
                                'PDN'   => '(Los Lagos)  CHADMO CENTRAL',
                                'OOL'   => '(Los Lagos)  CHAHUILCO',
                                'ZCN'   => '(Los Lagos)  CHAITEN',
                                'PZH'   => '(Los Lagos)  CHAMIZA',
                                'PWQ'   => '(Los Lagos)  CHAPARANO',
                                'PHC'   => '(Los Lagos)  CHAULINEC',
                                'OER'   => '(Los Lagos)  CHIRRE',
                                'PWS'   => '(Los Lagos)  CHOLGO',
                                'ZCH'   => '(Los Lagos)  CHONCHI',
                                'CMO'   => '(Los Lagos)  COCHAMO',
                                'PWI'   => '(Los Lagos)  COINCO - CASTRO',
                                'PCL'   => '(Los Lagos)  COLEGUAL - PUERTO MO',
                                'ZIX'   => '(Los Lagos)  CONCORDIA',
                                'OOA'   => '(Los Lagos)  CONTACO',
                                'PCM'   => '(Los Lagos)  CONTAO',
                                'PCN'   => '(Los Lagos)  CONTAY',
                                'PCT'   => '(Los Lagos)  CORRENTOSO',
                                'OOT'   => '(Los Lagos)  CORTE ALTO',
                                'OOR'   => '(Los Lagos)  CRUCERO',
                                'CUO'   => '(Los Lagos)  CUCAO',
                                'CVL'   => '(Los Lagos)  CURACO DE VELEZ',
                                'CGE'   => '(Los Lagos)  CURAHUE',
                                'DLE'   => '(Los Lagos)  DALCAHUE',
                                'PDG'   => '(Los Lagos)  DEGAN',
                                'PWA'   => '(Los Lagos)  EL BARRACO',
                                'ZEB'   => '(Los Lagos)  EL BOLSON',
                                'ZEE'   => '(Los Lagos)  EL ENCANTO ',
                                'ZEO'   => '(Los Lagos)  EL ISLOTE',
                                'ETL'   => '(Los Lagos)  EL TEPUAL',
                                'ENS'   => '(Los Lagos)  ENSENADA',
                                'ENL'   => '(Los Lagos)  ENTRE LAGOS',
                                'ZFI'   => '(Los Lagos)  FILUCO',
                                'FSA'   => '(Los Lagos)  FRESIA',
                                'FRT'   => '(Los Lagos)  FRUTILLAR',
                                'FTF'   => '(Los Lagos)  FUTALEUFU',
                                'GBN'   => '(Los Lagos)  GUALBUN',
                                'HRP'   => '(Los Lagos)  HORNOPIREN',
                                'HLH'   => '(Los Lagos)  HUALAIHUE',
                                'PXY'   => '(Los Lagos)  HUELMO',
                                'ZHY'   => '(Los Lagos)  HUEYUSCA',
                                'PHI'   => '(Los Lagos)  HUILDAD',
                                'HNO'   => '(Los Lagos)  HUILLINCO',
                                'ZHM'   => '(Los Lagos)  HUILMA',
                                'PHN'   => '(Los Lagos)  HUINAY',
                                'PWP'   => '(Los Lagos)  LA POSA',
                                'PLG'   => '(Los Lagos)  LAGO YELCHO',
                                'LDS'   => '(Los Lagos)  LAS CASCADAS',
                                'OSM'   => '(Los Lagos)  LAS LUMAS',
                                'PLS'   => '(Los Lagos)  LAS QUEMAS',
                                'PLW'   => '(Los Lagos)  LENCA',
                                'PLI'   => '(Los Lagos)  LINAO',
                                'PGX'   => '(Los Lagos)  LLANADA GRANDE',
                                'LLQ'   => '(Los Lagos)  LLANQUIHUE',
                                'PLU'   => '(Los Lagos)  LLIUCO',
                                'LLA'   => '(Los Lagos)  LOLCURA',
                                'LNT'   => '(Los Lagos)  LONCOTORO',
                                'ZEP'   => '(Los Lagos)  LOS BAJOS',
                                'ZEU'   => '(Los Lagos)  LOS CORRALES',
                                'LMU'   => '(Los Lagos)  LOS MUERMOS',
                                'PWT'   => '(Los Lagos)  LOS PELLINES - PUERT',
                                'OSC'   => '(Los Lagos)  LOS RISCOS',
                                'PMA'   => '(Los Lagos)  MAICHIHUE',
                                'ZWQ'   => '(Los Lagos)  MAICOLPUE',
                                'PMN'   => '(Los Lagos)  MANAO - CASTRO',
                                'MAU'   => '(Los Lagos)  MAULLIN',
                                'PME'   => '(Los Lagos)  MECHUQUE',
                                'OET'   => '(Los Lagos)  MILLANTUE',
                                'MSQ'   => '(Los Lagos)  MISQUIHUE',
                                'ZMV'   => '(Los Lagos)  MONTE VERDE',
                                'ZLY'   => '(Los Lagos)  NILQUE',
                                'NBR'   => '(Los Lagos)  NUEVA BRAUNAU',
                                'ZOS'   => '(Los Lagos)  OSORNO',
                                'PPU'   => '(Los Lagos)  PAILDAD',
                                'ZPJ'   => '(Los Lagos)  PAJARITOS',
                                'PLE'   => '(Los Lagos)  PALENA',
                                'PPA'   => '(Los Lagos)  PANGAL - PUERTO MONT',
                                'ZPY'   => '(Los Lagos)  PARAGUAY',
                                'PPD'   => '(Los Lagos)  PARGA',
                                'ZGA'   => '(Los Lagos)  PARGUA',
                                'PTH'   => '(Los Lagos)  PETROHUE',
                                'PPI'   => '(Los Lagos)  PICHANCO',
                                'OSD'   => '(Los Lagos)  PICHI DAMAS',
                                'PNG'   => '(Los Lagos)  PIEDRAS NEGRAS',
                                'PWY'   => '(Los Lagos)  POYO',
                                'PPR'   => '(Los Lagos)  PRIMER CORRAL',
                                'OOH'   => '(Los Lagos)  PUAUCHO',
                                'OEH'   => '(Los Lagos)  PUCATRIHUE',
                                'PPL'   => '(Los Lagos)  PUELO',
                                'PPP'   => '(Los Lagos)  PUELPUN',
                                'TCD'   => '(Los Lagos)  PUERTO CARDENAS',
                                'ZPK'   => '(Los Lagos)  PUERTO CLOCKER',
                                'XPF'   => '(Los Lagos)  PUERTO FONCK',
                                'PMC'   => '(Los Lagos)  PUERTO MONTT',
                                'PCY'   => '(Los Lagos)  PUERTO OCTAY',
                                'PIE'   => '(Los Lagos)  PUERTO PIEDRA',
                                'PRZ'   => '(Los Lagos)  PUERTO RAMIREZ',
                                'OOI'   => '(Los Lagos)  PUERTO RICO',
                                'ZPV'   => '(Los Lagos)  PUERTO VARAS',
                                'PQE'   => '(Los Lagos)  PUQUELDON',
                                'PRE'   => '(Los Lagos)  PURRANQUE',
                                'OLE'   => '(Los Lagos)  PURRAPEL',
                                'PYH'   => '(Los Lagos)  PUYEHUE',
                                'QLE'   => '(Los Lagos)  QUEILEN',
                                'QLN'   => '(Los Lagos)  QUELLON',
                                'QUV'   => '(Los Lagos)  QUELLON VIEJO',
                                'QUE'   => '(Los Lagos)  QUEMCHI',
                                'PQT'   => '(Los Lagos)  QUETELMAHUE',
                                'QIA'   => '(Los Lagos)  QUICAVI',
                                'PTE'   => '(Los Lagos)  QUILLAIPE',
                                'QCH'   => '(Los Lagos)  QUINCHAO',
                                'PRA'   => '(Los Lagos)  RALUN',
                                'RPM'   => '(Los Lagos)  RANCHO PUERTO MONTT',
                                'RQL'   => '(Los Lagos)  RANCHO QUELLON',
                                'ZRN'   => '(Los Lagos)  REFUGIO ANTILLANCA',
                                'ZRD'   => '(Los Lagos)  REFUGIO LA PICADA',
                                'ZRM'   => '(Los Lagos)  REMEHUE',
                                'PWF'   => '(Los Lagos)  RIO FRIO',
                                'RNC'   => '(Los Lagos)  RIO NEGRO',
                                'RIS'   => '(Los Lagos)  RIO SUR',
                                'PWZ'   => '(Los Lagos)  ROLLIZO',
                                'SJD'   => '(Los Lagos)  S.JUAN DE LA COSTA',
                                'JJN'   => '(Los Lagos)  SAN JUAN',
                                'SPL'   => '(Los Lagos)  SAN PABLO - OSORNO',
                                'PSE'   => '(Los Lagos)  SEGUNDO CORRAL',
                                'ZTG'   => '(Los Lagos)  TEGUALDA',
                                'TLE'   => '(Los Lagos)  TERMAS DE LLANCATUE',
                                'ZTH'   => '(Los Lagos)  TERMAS DE PUYEHUE',
                                'PTM'   => '(Los Lagos)  TERMAS EL AMARILLO',
                                'PTU'   => '(Los Lagos)  TEUPA',
                                'PWD'   => '(Los Lagos)  TRINCAO - CASTRO',
                                'PVI'   => '(Los Lagos)  VILLA SANTA LUCIA',
                                'PVL'   => '(Los Lagos)  VILLA VANGUARDIA',
                                'PYA'   => '(Los Lagos)  YALDAD',
                                'BBA'   => '(Aysén)  BALMACEDA',
                                'BNO'   => '(Aysén)  BANO NUEVO',
                                'TOR'   => '(Aysén)  CALETA TORTEL',
                                'CCH'   => '(Aysén)  CHILE CHICO',
                                'CNS'   => '(Aysén)  CISNES',
                                'CCL'   => '(Aysén)  COCHRANE',
                                'GXQ'   => '(Aysén)  COYHAIQUE',
                                'GAX'   => '(Aysén)  COYHAIQUE ALTO',
                                'IAU'   => '(Aysén)  EL GATO',
                                'GCA'   => '(Aysén)  GUAITECAS',
                                'GIA'   => '(Aysén)  ISLA ANGAMOS',
                                'GIB'   => '(Aysén)  ISLA BENJAMIN',
                                'GIC'   => '(Aysén)  ISLA CAMPANA',
                                'GIP'   => '(Aysén)  ISLA CUPTANA',
                                'GII'   => '(Aysén)  ISLA IPUN',
                                'GIZ'   => '(Aysén)  ISLA IZAZO',
                                'GIL'   => '(Aysén)  ISLA LEVEL',
                                'GIM'   => '(Aysén)  ISLA MELCHOR',
                                'GMJ'   => '(Aysén)  ISLA MERINO JARPA',
                                'GIN'   => '(Aysén)  ISLA NALCAYEC',
                                'GIY'   => '(Aysén)  ISLA PATRICIO LYNCH',
                                'GIV'   => '(Aysén)  ISLA VICTORIA',
                                'JUN'   => '(Aysén)  LA JUNTA - COYHAIQUE',
                                'GLT'   => '(Aysén)  LA TAPERA',
                                'ANE'   => '(Aysén)  LAGO COCHRANE',
                                'LVE'   => '(Aysén)  LAGO VERDE',
                                'GLS'   => '(Aysén)  LAGUNA SAN RAFAEL',
                                'GLV'   => '(Aysén)  LEVICAN',
                                'GMH'   => '(Aysén)  MANIHUALES',
                                'NKA'   => '(Aysén)  MELINKA',
                                'GMT'   => '(Aysén)  MINA EL TOQUI',
                                'GNG'   => '(Aysén)  NIREGUAO',
                                'OHG'   => '(Aysén)  O HIGGINS',
                                'AGR'   => '(Aysén)  PUERTO AGUIRRE',
                                'WPA'   => '(Aysén)  PUERTO AYSEN',
                                'PBI'   => '(Aysén)  PUERTO BERTRAND',
                                'PCC'   => '(Aysén)  PUERTO CHACABUCO',
                                'PCI'   => '(Aysén)  PUERTO CISNES',
                                'GPF'   => '(Aysén)  PUERTO FACHINAL',
                                'GVH'   => '(Aysén)  PUERTO GAVIOTA',
                                'PGU'   => '(Aysén)  PUERTO GUADAL',
                                'GXP'   => '(Aysén)  PUERTO HERRADURA',
                                'GIQ'   => '(Aysén)  PUERTO ING.IBANEZ',
                                'GPX'   => '(Aysén)  PUERTO MURTA',
                                'GPZ'   => '(Aysén)  PUERTO SANCHEZ',
                                'TGL'   => '(Aysén)  PUERTO TRANQUILO',
                                'GPY'   => '(Aysén)  PUERTO YUNGAY',
                                'YUH'   => '(Aysén)  PUYUHUAPI',
                                'GRC'   => '(Aysén)  RIO CISNES',
                                'RIB'   => '(Aysén)  RIO IBANEZ',
                                'GSM'   => '(Aysén)  SANTA MARIA DEL MAR',
                                'GTP'   => '(Aysén)  TERMAS DE PUYUHUAPI',
                                'TRT'   => '(Aysén)  TORTEL',
                                'VGL'   => '(Aysén)  VILLA AMENGUAL',
                                'VCC'   => '(Aysén)  VILLA CERRO CASTILLO',
                                'GVC'   => '(Aysén)  VILLA CHACABUCO',
                                'MHS'   => '(Aysén)  VILLA MANIHUALES',
                                'VOH'   => '(Aysén)  VILLA OHIGGINS',
                                'GVZ'   => '(Aysén)  VILLA ORTEGA',
                                'ATC'   => '(Magallanes y la Antartica Chilena)  ANTARTICA',
                                'ARM'   => '(Magallanes y la Antartica Chilena)  ARMONIA',
                                'CAB'   => '(Magallanes y la Antartica Chilena)  CABEZA DE MAR',
                                'HOR'   => '(Magallanes y la Antartica Chilena)  CABO DE HORNOS',
                                'CEU'   => '(Magallanes y la Antartica Chilena)  CALETA EUGENIA',
                                'PCX'   => '(Magallanes y la Antartica Chilena)  CAMERON',
                                'CEC'   => '(Magallanes y la Antartica Chilena)  CERRO CASTILLO ',
                                'CSM'   => '(Magallanes y la Antartica Chilena)  CERRO SOMBRERO',
                                'QEN'   => '(Magallanes y la Antartica Chilena)  CULLEN',
                                'EVT'   => '(Magallanes y la Antartica Chilena)  ENTRE VIENTOS',
                                'ECH'   => '(Magallanes y la Antartica Chilena)  ESTANCIA CHINA CR.',
                                'ELO'   => '(Magallanes y la Antartica Chilena)  ESTANCIA LOS OLIVOS',
                                'ESJ'   => '(Magallanes y la Antartica Chilena)  ESTANCIA SAN JUAN',
                                'PES'   => '(Magallanes y la Antartica Chilena)  ESTANCIA SN GREGORIO',
                                'ESV'   => '(Magallanes y la Antartica Chilena)  ESTANCIA VICTORINA',
                                'FBL'   => '(Magallanes y la Antartica Chilena)  FUERTE BULNES',
                                'GKE'   => '(Magallanes y la Antartica Chilena)  GAIKE',
                                'PGL'   => '(Magallanes y la Antartica Chilena)  GALLEGOS CHICOS',
                                'IDW'   => '(Magallanes y la Antartica Chilena)  ISLA DAWSON',
                                'INV'   => '(Magallanes y la Antartica Chilena)  ISLA NAVARINO',
                                'PLJ'   => '(Magallanes y la Antartica Chilena)  LA JUNTA  ',
                                'LBL'   => '(Magallanes y la Antartica Chilena)  LAGUNA BLANCA',
                                'LTA'   => '(Magallanes y la Antartica Chilena)  LAPATAIA',
                                'MTS'   => '(Magallanes y la Antartica Chilena)  MANANTIALES',
                                'MPK'   => '(Magallanes y la Antartica Chilena)  MINA PECKET',
                                'MAY'   => '(Magallanes y la Antartica Chilena)  MONTE AYMOND',
                                'MRC'   => '(Magallanes y la Antartica Chilena)  MORRO CHICO',
                                'ONA'   => '(Magallanes y la Antartica Chilena)  ONAISIN',
                                'PPG'   => '(Magallanes y la Antartica Chilena)  PAMPA GUANACOS',
                                'PHE'   => '(Magallanes y la Antartica Chilena)  PEHOE',
                                'ZPR'   => '(Magallanes y la Antartica Chilena)  PORVENIR - PUNTA ARE',
                                'PRI'   => '(Magallanes y la Antartica Chilena)  PRIMAVERA',
                                'PPN'   => '(Magallanes y la Antartica Chilena)  PUERTO ALTAMIRANO',
                                'UOR'   => '(Magallanes y la Antartica Chilena)  PUERTO ARTURO',
                                'PPB'   => '(Magallanes y la Antartica Chilena)  PUERTO BORIES',
                                'PPC'   => '(Magallanes y la Antartica Chilena)  PUERTO CONDOR',
                                'PNT'   => '(Magallanes y la Antartica Chilena)  PUERTO NATALES',
                                'PZP'   => '(Magallanes y la Antartica Chilena)  PUERTO PERCY',
                                'PTO'   => '(Magallanes y la Antartica Chilena)  PUERTO TORO',
                                'PWL'   => '(Magallanes y la Antartica Chilena)  PUERTO WILLIAMS',
                                'PPY'   => '(Magallanes y la Antartica Chilena)  PUERTO YARTAU',
                                'PUQ'   => '(Magallanes y la Antartica Chilena)  PUNTA ARENAS',
                                'PDU'   => '(Magallanes y la Antartica Chilena)  PUNTA DELGADA',
                                'RPU'   => '(Magallanes y la Antartica Chilena)  RANCHO PUNTA ARENAS',
                                'RGG'   => '(Magallanes y la Antartica Chilena)  RIO GRANDE',
                                'RTT'   => '(Magallanes y la Antartica Chilena)  RIO TURBIO',
                                'RVE'   => '(Magallanes y la Antartica Chilena)  RIO VERDE',
                                'RBS'   => '(Magallanes y la Antartica Chilena)  RUBENS',
                                'SGG'   => '(Magallanes y la Antartica Chilena)  SAN GREGORIO - PUNTA',
                                'KSB'   => '(Magallanes y la Antartica Chilena)  SAN SEBASTIAN',
                                'SRU'   => '(Magallanes y la Antartica Chilena)  SECCION RUSSFIN',
                                'TCN'   => '(Magallanes y la Antartica Chilena)  TERMINAL CABO NEGRO',
                                'PZA'   => '(Magallanes y la Antartica Chilena)  TERMINAL SAN GREGORI',
                                'PTI'   => '(Magallanes y la Antartica Chilena)  TIMAUKEL',
                                'TRP'   => '(Magallanes y la Antartica Chilena)  TORRES DEL PAINE',
                                'VTT'   => '(Magallanes y la Antartica Chilena)  VILLA TEHUELCHES',
                                'YEN'   => '(Magallanes y la Antartica Chilena)  YENDEGAIA'
                            )
                        ),
                        'serviceType' => array(
                            'title' => __('Seller\'s Service Type', 'bx'),
                            'required'    => true,
                            'type' => 'select',
                            'description' => __('Which service type are you going to use for shipments?', 'bx'),
                            'default' => __('EX', 'bx'),
                            'options' => array(
                                'EX'   => 'Express',
                                'PY'   => 'Priority',
                                'PR'   => 'Premium'
                            )
                        ),
                        'producto' => array(
                            'title' => __('Seller\'s Product', 'bx'),
                            'required'    => true,
                            'type' => 'select',
                            'description' => __('Which product are you going to use for shipments?', 'bx'),
                            'default' => __('P', 'bx'),
                            'options' => array(
                                'SYG' => 'Supermercado y Grandes Tiendas',
                                'P' => ' Paquete',
                                'SOB' =>  'Sobre'
                            )
                        ),
                        'familiaProducto' => array(
                            'title' => __('Seller\'s Family Product', 'bx'),
                            'required'    => true,
                            'type' => 'select',
                            'description' => __('Which family product are you going to use for shipments?', 'bx'),
                            'default' => __('PAQU', 'bx'),
                            'options' => array(
                                'SYGT' => 'Supermercado y Grandes Tiendas',
                                'PAQU' => 'Paquete',
                                'SOBR' => 'Sobre'
                            )
                        ),
                        'porcentajeVariacion' => array(
                            'title' => __('Variation Tax', 'bx'),
                            'required'    => true,
                            'type' => 'text',
                            'description' => __('It is a number that allows you to increase or decrease final cost of shipping. It can be positve or negative.', 'bx'),
                            'default' => __('0', 'bx')
                        ),
                    );
                }

                public function calculate_shipping($package = array())
                {
                    if ($this->bx_validate_order($package)) {
                        $this->get_bx_pricing($package);
                    }
                }

                function get_bx_pricing($package = array())
                {
                    $method = 'POST';
                    $url = $this->settings['bluexPricingRestURL'];
                    $header = array(
                        'Accept: application/json',
                        'Content-Type: application/json',
                        'BX-TOKEN: ' . $this->settings['bxToken'],
                        'BX-USERCODE: ' . $this->settings['bxUserCode'],
                        'BX-CLIENT_ACCOUNT: ' . $this->settings['clientAccount']
                    );
                    
                    $body = $this->get_body_pricing($package);
                    $bxPricingResponse = $this->call_api($method, $url, $header, json_encode($body));
                    $bxPricing = json_decode($bxPricingResponse, true);

                    if ($bxPricing == null) {
                        return;
                    }
                    if ($bxPricing['data'] == null) {
                        return;
                    }
                    if ($bxPricing['data']['total'] == null) {
                        return;
                    }
                    $variation =  $this->settings['porcentajeVariacion'];
                    if (!is_numeric($variation))
                        $variation = 0;

                    $variation = $bxPricing['data']['total'] * ($variation / 100);
                    $cost = $bxPricing['data']['total'] +  $variation;
                    $labelShipping = $this->title;
                    $rate =  array(
                        'id' => $this->id,
                        'label' => $labelShipping,
                        'cost' => $cost
                    );
                    $this->add_rate($rate);
                }

                function get_body_pricing($package)
                {
                    $sellerDistrict = $this->settings['sellerDistrict'];
                    $sellerCountry = $this->settings['sellerCountry'];
                    $serviceType = $this->settings['serviceType'];
                    $producto = $this->settings['producto'];
                    $familiaProducto = $this->settings['familiaProducto'];
                    $serviciosComplementarios = null;

                    $current_cc  = $package['destination']['country'];
                    $state_cc  = (int) $package['destination']['state'];
                    $city_cc  = $package['destination']['city'];
                    $largo = 0;
                    $ancho = 0;
                    $alto = 0;
                    $pesoFisico = 0;
                    $cantidadPiezas = 0;
                    $unidades = 0;
                    foreach ($package['contents'] as $item_id => $values) {
                        $_product = wc_get_product($values['product_id']);
                        $largo =  $largo + $_product->get_length();
                        $ancho =    $ancho + $_product->get_width();
                        $alto =   $alto +  $_product->get_height();
                        $cantidadPiezas =   $cantidadPiezas + $values['quantity'];
                        $unidades =  $unidades +  $values['quantity'];
                        $pesoFisico =  $pesoFisico +  ($_product->get_weight() *  +  $values['quantity']);
                    }
                    return  array(
                        'from'  => array(
                            'country' => $sellerCountry,
                            'district' => $sellerDistrict,
                        ),
                        'to' => array(
                            'country' => $current_cc,
                            'state' => $state_cc,
                            'district' => $city_cc,
                        ),
                        'serviceType' => $serviceType,
                        'serviciosComplementarios' => $serviciosComplementarios,
                        'datosProducto' => array(
                            'producto' => $producto,
                            'familiaProducto' => $familiaProducto,
                            'largo' => (pow($pesoFisico, 1 / 3) / 3),
                            'ancho' => (pow($pesoFisico, 1 / 3) / 3),
                            'alto' => (pow($pesoFisico, 1 / 3) / 3),
                            'pesoFisico' => $pesoFisico,
                            'cantidadPiezas' => $cantidadPiezas,
                            'unidades' => $unidades
                        )
                    );
                }
                function call_api($method, $url, $header, $data = false)
                {

                    $curl = curl_init();

                    switch ($method) {
                        case "POST":
                            curl_setopt($curl, CURLOPT_POST, 1);

                            if ($data)
                                curl_setopt($curl, CURLOPT_POSTFIELDS, $data);
                            break;
                        case "PUT":
                            curl_setopt($curl, CURLOPT_PUT, 1);
                            break;
                        default:
                            if ($data)
                                $url = sprintf("%s?%s", $url, http_build_query($data));
                    }


                    // pass header variable in curl method
                    curl_setopt($curl, CURLOPT_HTTPHEADER, $header);

                    curl_setopt($curl, CURLOPT_URL, $url);
                    curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);

                    $result = curl_exec($curl);

                    curl_close($curl);

                    return $result;
                }

                function bx_validate_order($package)
                {
                    $response = true;
                    $clientAccount = $this->settings['clientAccount'];
                    if ($clientAccount == null || trim($clientAccount) == '') {
                        $message = sprintf(__('Ups!, %s values param must be defined for %s.', 'bx'), ' clientAccount',  $this->title);
                        $messageType = "error";
                        if (!wc_has_notice($message, $messageType)) {
                            wc_add_notice($message, $messageType);
                        }
                        $response = false;
                    }

                    $bxToken = $this->settings['bxToken'];
                    if ($bxToken == null || trim($bxToken) == '') {
                        $message = sprintf(__('Ups!, %s values param must be defined for %s.', 'bx'), ' bxToken',  $this->title);
                        $messageType = "error";
                        if (!wc_has_notice($message, $messageType)) {
                            wc_add_notice($message, $messageType);
                        }
                        $response = false;
                    }

                    $bxUserCode = $this->settings['bxUserCode'];
                    if ($bxUserCode == null || trim($bxUserCode) == '') {
                        $message = sprintf(__('Ups!, %s values param must be defined for %s.', 'bx'), ' bxUserCode',  $this->title);
                        $messageType = "error";
                        if (!wc_has_notice($message, $messageType)) {
                            wc_add_notice($message, $messageType);
                        }
                        $response = false;
                    }

                    $bluexPricingRestURL = $this->settings['bluexPricingRestURL'];
                    if ($bluexPricingRestURL == null || trim($bluexPricingRestURL) == '') {
                        $message = sprintf(__('Ups!, %s values param must be defined for %s.', 'bx'), ' bluexPricingRestURL',  $this->title);
                        $messageType = "error";
                        if (!wc_has_notice($message, $messageType)) {
                            wc_add_notice($message, $messageType);
                        }
                        $response = false;
                    }

                    $sellerDistrict = $this->settings['sellerDistrict'];
                    if ($sellerDistrict == null || trim($sellerDistrict) == '') {
                        $message = sprintf(__('Ups!, %s values param must be defined for %s.', 'bx'), ' sellerDistrict',  $this->title);
                        $messageType = "error";
                        if (!wc_has_notice($message, $messageType)) {
                            wc_add_notice($message, $messageType);
                        }
                        $response = false;
                    }

                    $serviceType = $this->settings['serviceType'];
                    if ($serviceType == null || trim($serviceType) == '') {
                        $message = sprintf(__('Ups!, %s values param must be defined for %s.', 'bx'), ' serviceType',  $this->title);
                        $messageType = "error";
                        if (!wc_has_notice($message, $messageType)) {
                            wc_add_notice($message, $messageType);
                        }
                        $response = false;
                    }

                    $producto = $this->settings['producto'];
                    if ($producto == null || trim($producto) == '') {
                        $message = sprintf(__('Ups!, %s values param must be defined for %s.', 'bx'), ' producto',  $this->title);
                        $messageType = "error";
                        if (!wc_has_notice($message, $messageType)) {
                            wc_add_notice($message, $messageType);
                        }
                        $response = false;
                    }

                    $familiaProducto = $this->settings['familiaProducto'];
                    if ($familiaProducto == null || trim($familiaProducto) == '') {
                        $message = sprintf(__('Ups!, %s values param must be defined for %s.', 'bx'), ' familiaProducto',  $this->title);
                        $messageType = "error";
                        if (!wc_has_notice($message, $messageType)) {
                            wc_add_notice($message, $messageType);
                        }
                        $response = false;
                    }

                    foreach ($package['contents'] as $item_id => $values) {
                        $_product = wc_get_product($values['product_id']);
                        if ($_product->get_length() == null || $_product->get_length() == 0) {
                            $message = sprintf(__('Ups!, %s values param must be defined for %s. %s ', 'bx'), ' $_product->get_length()',  $_product->get_name(), $this->title);
                            $messageType = "error";
                            if (!wc_has_notice($message, $messageType)) {
                                wc_add_notice($message, $messageType);
                            }
                            $response = false;
                        }

                        if ($_product->get_weight() == null || $_product->get_weight() == 0) {
                            $message = sprintf(__('Ups!, %s values param must be defined for %s. %s ', 'bx'), ' $_product->get_weight()',  $_product->get_name(), $this->title);
                            $messageType = "error";
                            if (!wc_has_notice($message, $messageType)) {
                                wc_add_notice($message, $messageType);
                            }
                            $response = false;
                        }
                        if ($_product->get_width() == null || $_product->get_width() == 0) {
                            $message = sprintf(__('Ups!, %s values param must be defined for %s. %s ', 'bx'), ' $_product->get_width()',  $_product->get_name(), $this->title);
                            $messageType = "error";
                            if (!wc_has_notice($message, $messageType)) {
                                wc_add_notice($message, $messageType);
                            }
                            $response = false;
                        }
                        if ($_product->get_height() == null || $_product->get_height() == 0) {
                            $message = sprintf(__('Ups!, %s values param must be defined for %s. %s ', 'bx'), ' $_product->get_height()',  $_product->get_name(), $this->title);
                            $messageType = "error";
                            if (!wc_has_notice($message, $messageType)) {
                                wc_add_notice($message, $messageType);
                            }
                            $response = false;
                        }
                    }

                    return $response;
                }
            }
        }
    }

    add_action('woocommerce_shipping_init', 'bx_shipping_method');

    function add_bx_shipping_method($methods)
    {
        $methods[] = 'Bx_Shipping_Method';
        return $methods;
    }
    add_filter('woocommerce_shipping_methods', 'add_bx_shipping_method');

    // add_action('woocommerce_review_order_before_cart_contents', 'bx_validate_order', 10);
    // add_action('woocommerce_after_checkout_validation', 'bx_validate_order', 10);
}
